@@ -11,8 +11,9 @@
 #include "atask/Assist.h"
 #include "atask/Merge.h"
 #include "atask/Guard.h"
+#include "atask/Repair.h"
 
-class UnitType;
+struct UnitType;
 class AIClasses;
 class CGroup;
 class CUnit;
@@ -29,14 +30,14 @@ public:
 	/* Overload */
 	void remove(ARegistrar &task);
 
-	bool addTask(ATask *task);
+	bool addTask(ATask* task, ATask::NPriority p = ATask::NORMAL);
 
 	/* Get active task of group */
-	ATask* getTask(CGroup &group);
+	ATask* getTask(const CGroup& group);
 
 	ATask* getTaskByTarget(int);
 	/* Get the group destination */
-	float3 getPos(CGroup &group);
+	float3 getPos(const CGroup& group);
 	/* Update call */
 	void update();
 	/* Propagate "EnemyDestroyed" event to tasks */
