@@ -4,16 +4,20 @@
 #include <list>
 #include <set>
 #include <vector>
+#include <string>
 
 #include "System/float3.h"
 #include "IncCREG.h"
 #include "Defines.h"
 
-struct UnitDef;
+namespace springLegacyAI {
+	struct UnitDef;
+	class IGlobalAICallback;
+	class IAICallback;
+	class IAICheats;
+} // namespace springLegacyAI
+using namespace springLegacyAI;
 
-class IGlobalAICallback;
-class IAICallback;
-class IAICheats;
 class CMetalMap;
 class CMaths;
 class CPathFinder;
