@@ -1,6 +1,6 @@
 // _____________________________________________________
 //
-// RAI - Skirmish AI for TA Spring
+// RAI - Skirmish AI for Spring
 // Author: Reth / Michael Vadovszki
 // _____________________________________________________
 
@@ -10,7 +10,10 @@
 #include <string>
 
 using std::string;
-class IAICallback;
+namespace springLegacyAI {
+	class IAICallback;
+}
+using namespace springLegacyAI;
 
 
 class cLogFile
