@@ -1,34 +1,22 @@
-/*
-	Copyright (c) 2008 Robin Vobruba <hoijui.quaero@gmail.com>
+/* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-	This program is free software; you can redistribute it and/or modify
-	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation; either version 2 of the License, or
-	(at your option) any later version.
-
-	This program is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
-
-	You should have received a copy of the GNU General Public License
-	along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
-
-#ifndef _AIAICALLBACK_H
-#define _AIAICALLBACK_H
+#ifndef _AI_AI_CALLBACK_H
+#define _AI_AI_CALLBACK_H
 
 #include "IAICallback.h"
 
 struct SSkirmishAICallback;
 
+
+namespace springLegacyAI {
+
 /**
  * The AI side wrapper over the C AI interface for IAICallback.
  */
 class CAIAICallback : public IAICallback {
 public:
 	CAIAICallback();
-	CAIAICallback(int teamId, const SSkirmishAICallback* sAICallback);
+	CAIAICallback(int skirmishAIId, const SSkirmishAICallback* sAICallback);
 	~CAIAICallback();
 
 	void SendTextMsg(const char* text, int zone);
@@ -43,9 +31,11 @@ public:
 
 	int GetCurrentFrame();
 
+	int GetMySkirmishAIId();
 	int GetMyTeam();
 	int GetMyAllyTeam();
 	int GetPlayerTeam(int player);
+	int GetTeams();
 	const char* GetTeamSide(int teamId);
 	int GetTeamAllyTeam(int teamId);
 
@@ -80,6 +70,8 @@ public:
 	const std::vector<CommandDescription>* GetUnitCommands(int unitid);
 	const CCommandQueue* GetCurrentUnitCommands(int unitid);
 
+	int GetMaxUnits();
+
 	int GetUnitAiHint(int unitid);
 	int GetUnitTeam(int unitid);
 	int GetUnitAllyTeam(int unitid);
@@ -100,17 +92,17 @@ public:
 	bool IsUnitCloaked(int unitid);
 	bool IsUnitParalyzed(int unitid);
 	bool IsUnitNeutral(int unitid);
-	bool GetUnitResourceInfo(int unitid,
-			UnitResourceInfo* resourceInfo);
+	bool GetUnitResourceInfo(int unitid, UnitResourceInfo* resourceInfo);
 
 	const UnitDef* GetUnitDef(const char* unitName);
 	const UnitDef* GetUnitDefById(int unitDefId);
 
-	int InitPath(float3 start, float3 end, int pathType, float goalRadius = 8);
+	int InitPath(float3 start, float3 end, int pathType, float goalRadius);
 	float3 GetNextWaypoint(int pathid);
 	void FreePath(int pathid);
 
-	float GetPathLength(float3 start, float3 end, int pathType, float goalRadius = 8);
+	float GetPathLength(float3 start, float3 end, int pathType,
+			float goalRadius);
 
 	int GetEnemyUnits(int* unitIds, int unitIds_max);
 	int GetEnemyUnitsInRadarAndLos(int* unitIds, int unitIds_max);
@@ -240,15 +232,19 @@ public:
 
 	const float3* GetStartPos();
 
+	unsigned int GetCategoryFlag(const char* categoryName);
+	unsigned int GetCategoriesFlag(const char* categoryNames);
+	void GetCategoryName(int categoryFlag, char* name, int name_sizeMax);
 
-	const char* CallLuaRules(const char* data, int inSize = -1,
-			int* outSize = NULL);
+
+	const char* CallLuaRules(const char* inData, int inSize, int* outSize);
+	const char* CallLuaUI(const char* inData, int inSize, int* outSize);
 
 	std::map<std::string, std::string> GetMyInfo();
 	std::map<std::string, std::string> GetMyOptionValues();
 
 private:
-	int teamId;
+	int skirmishAIId;
 	const SSkirmishAICallback* sAICallback;
 
 	void init();
@@ -266,6 +262,7 @@ private:
 	CCommandQueue** unitCurrentCommandQueues;
 	FeatureDef** featureDefs;
 	int* featureDefFrames;
+	float3 startPos;
 
 	static size_t numClbInstances;
 	static float* heightMap;
@@ -277,4 +274,6 @@ private:
 	static unsigned char* metalMap;
 };
 
-#endif // _AIAICALLBACK_H
+} // namespace springLegacyAI
+
+#endif // _AI_AI_CALLBACK_H
