@@ -1,11 +1,11 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
 #include "UnitDef.h"
-#include "Sim/MoveTypes/MoveInfo.h"
+#include "MoveData.h"
 
 /******************************************************************************/
 
-UnitDef::UnitDefWeapon::UnitDefWeapon()
+springLegacyAI::UnitDef::UnitDefWeapon::UnitDefWeapon()
 : name("NOWEAPON")
 , def(NULL)
 , slavedTo(0)
@@ -17,7 +17,7 @@ UnitDef::UnitDefWeapon::UnitDefWeapon()
 {
 }
 
-UnitDef::UnitDefWeapon::UnitDefWeapon(
+springLegacyAI::UnitDef::UnitDefWeapon::UnitDefWeapon(
 	std::string name, const WeaponDef* def, int slavedTo, float3 mainDir, float maxAngleDif,
 	unsigned int badTargetCat, unsigned int onlyTargetCat, float fuelUse)
 : name(name)
@@ -34,10 +34,9 @@ UnitDef::UnitDefWeapon::UnitDefWeapon(
 
 /******************************************************************************/
 
-UnitDef::UnitDef()
+springLegacyAI::UnitDef::UnitDef()
 : valid(true)
 , id(-1)
-, collisionVolume(NULL)
 , decoyDef(NULL)
 , aihint(0)
 , cobID(-1)
@@ -115,7 +114,6 @@ UnitDef::UnitDef()
 , stockpileWeaponDef(NULL)
 , maxWeaponRange(0.0f)
 , maxCoverage(0.0f)
-, buildPic(NULL)
 , canSelfD(true)
 , selfDCountdown(0)
 , canSubmerge(false)
@@ -253,7 +251,7 @@ UnitDef::UnitDef()
 }
 
 
-UnitDef::~UnitDef()
+springLegacyAI::UnitDef::~UnitDef()
 {
 	delete movedata; movedata = NULL;
 
