@@ -83,6 +83,7 @@
 #include "Lua/LuaOpenGL.h"
 #include "Lua/LuaParser.h"
 #include "Lua/LuaSyncedRead.h"
+#include "Lua/LuaUI.h"
 #include "Lua/LuaUnsyncedCtrl.h"
 #include "Map/BaseGroundDrawer.h"
 #include "Map/MapDamage.h"
@@ -114,7 +115,6 @@
 #include "Sim/Units/Scripts/UnitScriptEngine.h"
 #include "Sim/Units/UnitDefHandler.h"
 #include "Sim/Units/Groups/GroupHandler.h"
-#include "Sim/Units/UnitLoader.h"
 #include "Sim/Weapons/Weapon.h"
 #include "Sim/Weapons/WeaponDefHandler.h"
 #include "UI/CommandColors.h"
@@ -126,7 +126,6 @@
 #include "UI/InfoConsole.h"
 #include "UI/KeyBindings.h"
 #include "UI/KeyCodes.h"
-#include "UI/LuaUI.h"
 #include "UI/MiniMap.h"
 #include "UI/MouseHandler.h"
 #include "UI/QuitBox.h"
@@ -176,6 +175,7 @@ CONFIG(bool, ShowFPS).defaultValue(false);
 CONFIG(bool, ShowClock).defaultValue(true);
 CONFIG(bool, ShowSpeed).defaultValue(false);
 CONFIG(bool, ShowMTInfo).defaultValue(true);
+CONFIG(float, MTInfoThreshold).defaultValue(0.25f);
 CONFIG(int, ShowPlayerInfo).defaultValue(1);
 CONFIG(float, GuiOpacity).defaultValue(0.8f);
 CONFIG(std::string, InputTextGeo).defaultValue("");
@@ -190,15 +190,13 @@ CR_BIND(CGame, (std::string(""), std::string(""), NULL));
 CR_REG_METADATA(CGame,(
 //	CR_MEMBER(finishedLoading),
 //	CR_MEMBER(drawMode),
-//	CR_MEMBER(fps),
 //	CR_MEMBER(thisFps),
 	CR_MEMBER(lastSimFrame),
-//	CR_MEMBER(fpstimer),
-//	CR_MEMBER(starttime),
-//	CR_MEMBER(lastUpdate),
-//	CR_MEMBER(lastMoveUpdate),
+//	CR_MEMBER(frameStartTime),
+//	CR_MEMBER(lastUpdateTime),
+//	CR_MEMBER(lastSimFrameTime),
+//	CR_MEMBER(lastDrawFrameUpdate),
 //	CR_MEMBER(lastModGameTimeMeasure),
-//	CR_MEMBER(lastUpdateRaw),
 //	CR_MEMBER(updateDeltaSeconds),
 	CR_MEMBER(totalGameTime),
 	CR_MEMBER(userInputPrefix),
@@ -214,6 +212,7 @@ CR_REG_METADATA(CGame,(
 	CR_MEMBER(showClock),
 	CR_MEMBER(showSpeed),
 	CR_MEMBER(showMTInfo),
+	CR_MEMBER(mtInfoThreshold),
 	CR_MEMBER(mtInfoCtrl),
 	CR_MEMBER(noSpectatorChat),
 	CR_MEMBER(gameID),
@@ -239,45 +238,52 @@ CR_REG_METADATA(CGame,(
 
 
 
-CGame::CGame(const std::string& mapName, const std::string& modName, ILoadSaveHandler* saveFile) :
-	gameDrawMode(gameNotDrawing),
-	defsParser(NULL),
-	fps(0),
-	thisFps(0),
-	lastSimFrame(-1),
-
-	totalGameTime(0),
-
-	hideInterface(false),
-
-	gameOver(false),
-
-	noSpectatorChat(false),
-	finishedLoading(false),
-
-	infoConsole(NULL),
-	consoleHistory(NULL),
-
-	skipping(false),
-	playing(false),
-	chatting(false),
-	lastFrameTime(0),
-
-	leastQue(0),
-	timeLeft(0.0f),
-	consumeSpeed(1.0f),
-	luaLockTime(0),
-	luaExportSize(0),
-
-	saveFile(saveFile),
-
-	worldDrawer(NULL)
+CGame::CGame(const std::string& mapName, const std::string& modName, ILoadSaveHandler* saveFile)
+	: finishedLoading(false)
+	, gameOver(false)
+	, gameDrawMode(gameNotDrawing)
+	, defsParser(NULL)
+	, thisFps(0)
+	, lastSimFrame(-1)
+	, frameStartTime(spring_gettime())
+	, lastUpdateTime(spring_gettime())
+	, lastSimFrameTime(spring_gettime())
+	, lastDrawFrameUpdate(spring_gettime())
+	, lastModGameTimeMeasure(spring_gettime())
+	, updateDeltaSeconds(0.0f)
+	, lastCpuUsageTime(0.0f)
+	, totalGameTime(0)
+	, hideInterface(false)
+	, noSpectatorChat(false)
+	, skipping(false)
+	, playing(false)
+	, chatting(false)
+	, leastQue(0)
+	, timeLeft(0.0f)
+	, consumeSpeed(1.0f)
+	, lastframe(spring_gettime())
+	, skipStartFrame(0)
+	, skipEndFrame(0)
+	, skipTotalFrames(0)
+	, skipSeconds(0.0f)
+	, skipSoundmute(false)
+	, skipOldSpeed(0.0f)
+	, skipOldUserSpeed(0.0f)
+	, skipLastDraw(spring_gettime())
+	, speedControl(-1)
+	, luaLockTime(0)
+	, luaExportSize(0)
+	, saveFile(saveFile)
+	, infoConsole(NULL)
+	, consoleHistory(NULL)
+	, worldDrawer(NULL)
 {
 	game = this;
 
 	memset(gameID, 0, sizeof(gameID));
 
-	time(&starttime);
+	frameStartTime = spring_gettime();
+	lastFrameTime  = spring_gettime();
 	lastTick = clock();
 
 	for (int a = 0; a < 8; ++a) { camMove[a] = false; }
@@ -300,6 +306,7 @@ CGame::CGame(const std::string& mapName, const std::string& modName, ILoadSaveHa
 	showClock = configHandler->GetBool("ShowClock");
 	showSpeed = configHandler->GetBool("ShowSpeed");
 	showMTInfo = configHandler->GetBool("ShowMTInfo");
+	mtInfoThreshold = configHandler->GetFloat("MTInfoThreshold");
 	mtInfoCtrl = 0;
 
 	speedControl = configHandler->GetInt("SpeedControl");
@@ -338,6 +345,8 @@ CGame::~CGame()
 	tracefile << "[" << __FUNCTION__ << "]";
 #endif
 
+	ENTER_SYNCED_CODE();
+
 	// Kill all teams that are still alive, in
 	// case the game did not do so through Lua.
 	for (int t = 0; t < teamHandler->ActiveTeams(); ++t) {
@@ -351,7 +360,6 @@ CGame::~CGame()
 	SyncedGameCommands::DestroyInstance();
 
 	IVideoCapturing::FreeInstance();
-	ISound::Shutdown();
 
 	CLuaGaia::FreeHandler();
 	CLuaRules::FreeHandler();
@@ -394,7 +402,6 @@ CGame::~CGame()
 	SafeDelete(cubeMapHandler);
 	SafeDelete(modelParser);
 
-	SafeDelete(unitLoader);
 	SafeDelete(pathManager);
 	SafeDelete(ground);
 	SafeDelete(smoothGround);
@@ -425,19 +432,21 @@ CGame::~CGame()
 
 	SafeDelete(gameServer);
 	SafeDelete(net);
+	ISound::Shutdown();
 
 	game = NULL;
+
+	LEAVE_SYNCED_CODE();
 }
 
 
 void CGame::LoadGame(const std::string& mapName)
 {
-#ifdef USE_GML
-	set_threadnum(GML_LOAD_THREAD_NUM);
-#endif
+	GML::ThreadNumber(GML_LOAD_THREAD_NUM);
 
 	Watchdog::RegisterThread(WDT_LOAD);
 
+
 	if (!gu->globalQuit) LoadDefs();
 	if (!gu->globalQuit) LoadSimulation(mapName);
 	if (!gu->globalQuit) LoadRendering();
@@ -456,6 +465,8 @@ void CGame::LoadGame(const std::string& mapName)
 
 void CGame::LoadDefs()
 {
+	ENTER_SYNCED_CODE();
+
 	{
 		loadscreen->SetLoadMessage("Loading Radar Icons");
 		icon::iconHandler = new icon::CIconHandler();
@@ -506,10 +517,14 @@ void CGame::LoadDefs()
 		sound->LoadSoundDefs("gamedata/sounds.lua");
 		chatSound = sound->GetSoundId("IncomingChat", false);
 	}
+
+	LEAVE_SYNCED_CODE();
 }
 
 void CGame::LoadSimulation(const std::string& mapName)
 {
+	ENTER_SYNCED_CODE();
+
 	// after this, other components are able to register chat action-executors
 	SyncedGameCommands::CreateInstance();
 	UnsyncedGameCommands::CreateInstance();
@@ -550,7 +565,6 @@ void CGame::LoadSimulation(const std::string& mapName)
 	weaponDefHandler = new CWeaponDefHandler();
 	loadscreen->SetLoadMessage("Loading Unit Definitions");
 	unitDefHandler = new CUnitDefHandler();
-	unitLoader = new CUnitLoader();
 
 	CGroundMoveType::CreateLineTable();
 
@@ -566,7 +580,7 @@ void CGame::LoadSimulation(const std::string& mapName)
 	loshandler = new CLosHandler();
 	radarhandler = new CRadarHandler(false);
 
-	pathManager = IPathManager::GetInstance();
+	pathManager = IPathManager::GetInstance(modInfo.pathFinderSystem);
 
 	wind.LoadWind(mapInfo->atmosphere.minWind, mapInfo->atmosphere.maxWind);
 
@@ -580,6 +594,8 @@ void CGame::LoadSimulation(const std::string& mapName)
 
 	syncedGameCommands->AddDefaultActionExecutors();
 	unsyncedGameCommands->AddDefaultActionExecutors();
+
+	LEAVE_SYNCED_CODE();
 }
 
 void CGame::LoadRendering()
@@ -676,6 +692,7 @@ void CGame::LoadInterface()
 void CGame::LoadLua()
 {
 	// Lua components
+	ENTER_SYNCED_CODE();
 	loadscreen->SetLoadMessage("Loading LuaRules");
 	CLuaRules::LoadHandler();
 
@@ -683,6 +700,7 @@ void CGame::LoadLua()
 		loadscreen->SetLoadMessage("Loading LuaGaia");
 		CLuaGaia::LoadHandler();
 	}
+	LEAVE_SYNCED_CODE();
 
 	loadscreen->SetLoadMessage("Loading LuaUI");
 	CLuaUI::LoadHandler();
@@ -699,11 +717,10 @@ void CGame::LoadFinalize()
 	loadscreen->SetLoadMessage("Finalizing");
 	eventHandler.GamePreload();
 
-	lastframe = SDL_GetTicks();
+	lastframe = spring_gettime();
 	lastModGameTimeMeasure = lastframe;
-	lastUpdate = lastframe;
-	lastMoveUpdate = lastframe;
-	lastUpdateRaw = lastframe;
+	lastSimFrameTime = lastframe;
+	lastDrawFrameUpdate = lastframe;
 	lastCpuUsageTime = gu->gameTime;
 	updateDeltaSeconds = 0.0f;
 
@@ -823,50 +840,25 @@ int CGame::KeyReleased(unsigned short k)
 
 bool CGame::Update()
 {
+	//TODO move as much as possible unsynced code out of this function
+
 	good_fpu_control_registers("CGame::Update");
 
-	unsigned timeNow = SDL_GetTicks();
+	const spring_time timeNow = spring_gettime();
+	const float diffsecs = spring_tomsecs(spring_difftime(timeNow, lastUpdateTime)) / 1000.0f;
 
-	const unsigned difTime = (timeNow - lastModGameTimeMeasure);
-	const float dif = skipping ? 0.010f : (float)difTime * 0.001f;
+	if (diffsecs >= 1.0f) { // do once every second
+		lastUpdateTime = timeNow;
 
-	if (!gs->paused) {
-		gu->modGameTime += dif * gs->speedFactor;
-	}
-
-	gu->gameTime += dif;
-
-	if (playing && !gameOver) {
-		totalGameTime += dif;
-	}
-
-	lastModGameTimeMeasure = timeNow;
-
-	time(&fpstimer);
-
-	if (difftime(fpstimer, starttime) != 0) { // do once every second
-		fps = thisFps;
-		thisFps = 0;
-
-		starttime = fpstimer;
-#if defined(USE_GML) && GML_ENABLE_SIM
-		extern int backupSize;
-		luaExportSize = backupSize;
-		backupSize = 0;
-		luaLockTime = (int)GML_LOCK_TIME();
-		float amount = (showMTInfo == MT_LUA_DUAL_EXPORT) ? (float)luaExportSize / 1000.0f : (float)luaLockTime / 10.0f;
-		if (amount >= 0.1f) {
-			if ((mtInfoCtrl = std::min(mtInfoCtrl + 1, 9)) == 5) mtInfoCtrl = 9;
-		}
-		else if ((mtInfoCtrl = std::max(mtInfoCtrl - 1, 0)) == 4) mtInfoCtrl = 0;
-#endif
+		// Some netcode stuff
 		if (!gameServer) {
-			consumeSpeed = ((float)(GAME_SPEED * gs->speedFactor + leastQue - 2));
+			consumeSpeed = GAME_SPEED * gs->speedFactor + leastQue - 2;
 			leastQue = 10000;
 			timeLeft = 0.0f;
 		}
 	}
 
+	//TODO: why? it already gets called with `true` in ::Draw()?
 	if (!skipping)
 	{
 		UpdateUI(false);
@@ -874,14 +866,13 @@ bool CGame::Update()
 
 	net->Update();
 
+	// When video recording do step by step simulation, so each simframe gets a corresponding videoframe
 	if (videoCapturing->IsCapturing() && playing && gameServer) {
 		gameServer->CreateNewFrame(false, true);
 	}
 
-	if (gs->frameNum == 0 || gs->paused)
-		eventHandler.UpdateObjects(); // we must add new rendering objects even if the game has not started yet
-
-	ClientReadNet();
+	ENTER_SYNCED_CODE();
+	ClientReadNet(); // this can issue new SimFrame()s
 
 	if (net->NeedsReconnect() && !gameOver) {
 		extern ClientSetup* startsetup;
@@ -889,31 +880,179 @@ bool CGame::Update()
 	}
 
 	if (net->CheckTimeout(0, gs->frameNum == 0) && !gameOver) {
-		LOG_L(L_WARNING, "Lost connection to gameserver");
+		LOG_L(L_ERROR, "Lost connection to gameserver");
 		GameEnd(std::vector<unsigned char>());
 	}
+	LEAVE_SYNCED_CODE();
 
-	// send out new console lines
-	if (infoConsole) {
-		vector<CInfoConsole::RawLine> lines;
-		infoConsole->GetNewRawLines(lines);
-		for (unsigned int i = 0; i < lines.size(); i++) {
-			const CInfoConsole::RawLine& rawLine = lines[i];
-			eventHandler.AddConsoleLine(rawLine.text, rawLine.section, rawLine.level);
-		}
-	}
-
-	if (!(gs->frameNum & 31)) {
-		oscStatsSender->Update(gs->frameNum);
-	}
+	//TODO move this to ::Draw()?
+	if (gs->frameNum == 0 || gs->paused)
+		eventHandler.UpdateObjects(); // we must add new rendering objects even if the game has not started yet
 
 	return true;
 }
 
 
+bool CGame::UpdateUnsynced()
+{
+	// timings and frame interpolation
+	const spring_time currentTime = spring_gettime();
+
+	const float difTime = spring_tomsecs(currentTime - lastModGameTimeMeasure);
+	const float dif = skipping ? 0.010f : difTime * 0.001f;
+	lastModGameTimeMeasure = currentTime;
+
+	// Update game times
+	gu->gameTime += dif;
+	gu->modGameTime += (gs->paused) ? 0.0f : dif * gs->speedFactor;
+	if (playing && !gameOver) {
+		totalGameTime += dif;
+	}
+	updateDeltaSeconds = dif;
+
+	// FastForwarding
+	if (skipping) {
+		const float diff = spring_tomsecs(currentTime - skipLastDraw);
+
+		if (diff < 500) // render at 2 FPS
+			return true;
+		skipLastDraw = currentTime;
+
+		if (!GML::SimEnabled() || !GML::MultiThreadSim()) {
+			DrawSkip();
+			return true;
+		}
+	}
+
+	thisFps++;
+	globalRendering->drawFrame = std::max(1U, globalRendering->drawFrame + 1);
+
+	// Update the interpolation coefficient (globalRendering->timeOffset)
+	if (!gs->paused && !HasLag() && gs->frameNum>1 && !videoCapturing->IsCapturing()) {
+		globalRendering->lastFrameStart = currentTime;
+		globalRendering->weightedSpeedFactor = 0.001f * GAME_SPEED * gs->userSpeedFactor;
+		globalRendering->timeOffset = spring_tomsecs(globalRendering->lastFrameStart - lastSimFrameTime) * globalRendering->weightedSpeedFactor;
+	} else  {
+		globalRendering->timeOffset = 0;
+		lastSimFrameTime = currentTime;
+	}
+
+	// do once every second
+	const float diffsecs = spring_diffsecs(currentTime, frameStartTime);
+	if (diffsecs >= 1.0f) {
+		frameStartTime = currentTime;
+
+		// Update FPS
+		globalRendering->FPS = thisFps / diffsecs;
+		thisFps = 0;
+
+		if (GML::SimEnabled()) {
+			// Update Lua lock time warning
+			extern int backupSize;
+			luaExportSize = backupSize;
+			backupSize = 0;
+			luaLockTime = (int)GML_LOCK_TIME();
+			float amount = (showMTInfo == MT_LUA_DUAL_EXPORT) ? luaExportSize / 1000.0f : luaLockTime / 10.0f;
+			if (amount >= mtInfoThreshold) {
+				if ((mtInfoCtrl = std::min(mtInfoCtrl + 1, 9)) == 5) mtInfoCtrl = 9;
+			}
+			else if ((mtInfoCtrl = std::max(mtInfoCtrl - 1, 0)) == 4) mtInfoCtrl = 0;
+		}
+	}
+
+	const bool doDrawWorld = hideInterface || !minimap->GetMaximized() || minimap->GetMinimized();
+	const bool newSimFrame = (lastSimFrame != gs->frameNum);
+	lastSimFrame = gs->frameNum;
+
+	// set camera
+	camHandler->UpdateCam();
+	camera->Update();
+
+	CBaseGroundDrawer* gd = readmap->GetGroundDrawer();
+	if (doDrawWorld) {
+		// do as early as possible (give OpenGL time to upload textures etc.)
+		{
+			SCOPED_TIMER("GroundDrawer::Update");
+			gd->Update();
+		}
+
+		if (newSimFrame) {
+			projectileDrawer->UpdateTextures();
+			sky->Update();
+			sky->GetLight()->Update();
+			water->Update();
+		}
+
+		CNamedTextures::Update();
+		texturehandlerS3O->Update();
+		modelParser->Update();
+		worldDrawer->Update();
+	}
+
+
+	if (newSimFrame) {
+		CInputReceiver::CollectGarbage();
+	
+		if (!(gs->frameNum & 31)) {
+			oscStatsSender->Update(gs->frameNum);
+		}
+	}
+
+	// always update ExtraTexture & SoundListener with <=30Hz (even when paused)
+	if (newSimFrame || gs->paused) {
+		static spring_time lastUpdate = spring_gettime();
+		const float deltaSec = spring_diffsecs(currentTime, lastUpdate);
+
+		if (!gs->paused || deltaSec >= (1.0f/GAME_SPEED)) {
+			lastUpdate = currentTime;
+
+			{
+				SCOPED_TIMER("GroundDrawer::UpdateExtraTex");
+				gd->UpdateExtraTexture();
+			}
+
+			// TODO call only when camera changed
+			sound->UpdateListener(camera->pos, camera->forward, camera->up, deltaSec);
+		}
+	}
+
+	UpdateUI(true);
+
+	SetDrawMode(gameNormalDraw); //TODO move to ::Draw()?
+
+	if (luaUI)    { luaUI->CheckStack(); luaUI->ExecuteUIEventBatch(); }
+	if (luaGaia)  { luaGaia->CheckStack(); }
+	if (luaRules) { luaRules->CheckStack(); }
+
+	// XXX ugly hack to minimize luaUI errors
+	if (luaUI && luaUI->GetCallInErrors() >= 5) {
+		for (int annoy = 0; annoy < 8; annoy++) {
+			LOG_L(L_ERROR, "5 errors deep in LuaUI, disabling...");
+		}
+
+		guihandler->PushLayoutCommand("disable");
+		LOG_L(L_ERROR, "Type '/luaui reload' in the chat to re-enable LuaUI.");
+		LOG_L(L_ERROR, "===>>>  Please report this error to the forum or mantis with your infolog.txt");
+	}
+
+	assert(infoConsole);
+	infoConsole->PushNewLinesToEventHandler();
+
+	configHandler->Update();
+	mouse->Update();
+	mouse->UpdateCursors();
+	guihandler->Update();
+
+	LuaUnsyncedCtrl::ClearUnitCommandQueues();
+	eventHandler.Update();
+
+	return false;
+}
+
+
 #if defined(USE_GML) && GML_ENABLE_DRAW
 bool CGame::Draw() {
-	gmlProcessor->Work(&CGame::DrawMTcb,NULL,NULL,this,gmlThreadCount,TRUE,NULL,1,2,2,FALSE);
+	gmlProcessor->Work(&CGame::DrawMTcb,NULL,NULL,this,GML::ThreadCount(),TRUE,NULL,1,2,2,FALSE);
 	return true;
 }
 #else
@@ -930,124 +1069,22 @@ bool CGame::Draw() {
 #endif
 	GML_STDMUTEX_LOCK(draw); //Draw
 
-	//! timings and frame interpolation
-	const unsigned currentTime = SDL_GetTicks();
-
-	if (skipping) {
-		if (skipLastDraw + 500 > currentTime) // render at 2 FPS
-			return true;
-		skipLastDraw = currentTime;
-#if defined(USE_GML) && GML_ENABLE_SIM
-		if (!gmlMultiThreadSim)
-#endif
-		{
-			DrawSkip();
-			return true;
-		}
-	}
-
-	thisFps++;
-
-	updateDeltaSeconds = 0.001f * float(currentTime - lastUpdateRaw);
-	lastUpdateRaw = SDL_GetTicks();
-	if (!gs->paused && !HasLag() && gs->frameNum>1 && !videoCapturing->IsCapturing()) {
-		globalRendering->lastFrameStart = SDL_GetTicks();
-		globalRendering->weightedSpeedFactor = 0.001f * GAME_SPEED * gs->speedFactor;
-		globalRendering->timeOffset = (float)(globalRendering->lastFrameStart - lastUpdate) * globalRendering->weightedSpeedFactor;
-	} else  {
-		globalRendering->timeOffset=0;
-		lastUpdate = SDL_GetTicks();
-	}
-
-
-	const bool doDrawWorld = hideInterface || !minimap->GetMaximized() || minimap->GetMinimized();
-
-	//! set camera
-	camHandler->UpdateCam();
-	camera->Update();
+	if (UpdateUnsynced())
+		return true;
 
 	CBaseGroundDrawer* gd = readmap->GetGroundDrawer();
-	if (doDrawWorld) {
-		{
-			SCOPED_TIMER("GroundDrawer::Update");
-			gd->Update();
-		}
 
-		if (lastSimFrame != gs->frameNum && !skipping) {
-			projectileDrawer->UpdateTextures();
-			sky->Update();
-			sky->GetLight()->Update();
-			water->Update();
-		}
-	}
+	const bool doDrawWorld = hideInterface || !minimap->GetMaximized() || minimap->GetMinimized();
+	const spring_time currentTime = spring_gettime();
 
-
-	if (lastSimFrame != gs->frameNum) {
-		CInputReceiver::CollectGarbage();
-	}
-
-	//! always update ExtraTexture & SoundListener with <=30Hz (even when paused)
-	if (!skipping) {
-		bool newSimFrame = (lastSimFrame != gs->frameNum);
-		if (newSimFrame || gs->paused) {
-			static unsigned lastUpdate = SDL_GetTicks();
-			unsigned deltaMSec = currentTime - lastUpdate;
-
-			if (!gs->paused || deltaMSec >= 1000/30.f) {
-				lastUpdate = currentTime;
-
-				{
-					SCOPED_TIMER("GroundDrawer::UpdateExtraTex");
-					gd->UpdateExtraTexture();
-				}
-
-				// TODO call only when camera changed
-				sound->UpdateListener(camera->pos, camera->forward, camera->up, deltaMSec / 1000.f);
-			}
-		}
-	}
-
-	lastSimFrame = gs->frameNum;
-
-	if (!skipping)
-		UpdateUI(true);
-
-	SetDrawMode(gameNormalDraw);
-
- 	if (luaUI)    { luaUI->CheckStack(); luaUI->ExecuteUIEventBatch(); }
-	if (luaGaia)  { luaGaia->CheckStack(); }
-	if (luaRules) { luaRules->CheckStack(); }
-
-	// XXX ugly hack to minimize luaUI errors
-	if (luaUI && luaUI->GetCallInErrors() >= 5) {
-		for (int annoy = 0; annoy < 8; annoy++) {
-			LOG_L(L_ERROR, "5 errors deep in LuaUI, disabling...");
-		}
-
-		guihandler->PushLayoutCommand("disable");
-		LOG_L(L_ERROR, "Type '/luaui reload' in the chat to re-enable LuaUI.");
-		LOG_L(L_ERROR, "===>>>  Please report this error to the forum or mantis with your infolog.txt");
-	}
-
-	configHandler->Update();
-	CNamedTextures::Update();
-	texturehandlerS3O->Update();
-	modelParser->Update();
-	worldDrawer->Update();
-	mouse->Update();
-	mouse->UpdateCursors();
-	guihandler->Update();
-
-	LuaUnsyncedCtrl::ClearUnitCommandQueues();
-	eventHandler.Update();
 	eventHandler.DrawGenesis();
 
 	if (!globalRendering->active) {
-		SDL_Delay(10); // milliseconds
+		spring_sleep(spring_msecs(10));
 		return true;
 	}
 
-	CTeamHighlight::Enable(currentTime);
+	CTeamHighlight::Enable(spring_tomsecs(currentTime));
 
 	if (unitTracker.Enabled()) {
 		unitTracker.SetCam();
@@ -1113,6 +1150,8 @@ bool CGame::Draw() {
 
 	glDisable(GL_FOG);
 
+	SCOPED_TIMER("Game::DrawScreen");
+
 	if (doDrawWorld) {
 		eventHandler.DrawScreenEffects();
 	}
@@ -1142,8 +1181,8 @@ bool CGame::Draw() {
 	if (globalRendering->drawdebug) {
 		//print some infos (fps,gameframe,particles)
 		glColor4f(1,1,0.5f,0.8f);
-		font->glFormat(0.03f, 0.02f, 1.0f, FONT_SCALE | FONT_NORM, "FPS: %d Frame: %d Particles: %d (%d)",
-		    fps, gs->frameNum, ph->syncedProjectiles.size() + ph->unsyncedProjectiles.size(), ph->currentParticles);
+		font->glFormat(0.03f, 0.02f, 1.0f, FONT_SCALE | FONT_NORM, "FPS: %0.1f Frame: %d Particles: %d (%d)",
+		    globalRendering->FPS, gs->frameNum, ph->syncedProjectiles.size() + ph->unsyncedProjectiles.size(), ph->currentParticles);
 
 		if (playing) {
 			font->glFormat(0.03f, 0.07f, 0.7f, FONT_SCALE | FONT_NORM, "xpos: %5.0f ypos: %5.0f zpos: %5.0f speed %2.2f",
@@ -1185,7 +1224,7 @@ bool CGame::Draw() {
 
 		if (showFPS) {
 			char buf[32];
-			SNPRINTF(buf, sizeof(buf), "%i", fps);
+			SNPRINTF(buf, sizeof(buf), "%.0f", globalRendering->FPS);
 
 			const float4 yellow(1.0f, 1.0f, 0.25f, 1.0f);
 			smallFont->SetColors(&yellow,NULL);
@@ -1200,38 +1239,34 @@ bool CGame::Draw() {
 			smallFont->SetColors(&speedcol, NULL);
 			smallFont->glPrint(0.99f, 0.90f, 1.0f, font_options, buf);
 		}
-
-#if defined(USE_GML) && GML_ENABLE_SIM
-		if (mtInfoCtrl >= 5 && (showMTInfo == MT_LUA_SINGLE || showMTInfo == MT_LUA_SINGLE_BATCH || showMTInfo == MT_LUA_DUAL_EXPORT)) {
+		
+		if (GML::SimEnabled() && mtInfoCtrl >= 5 && (showMTInfo == MT_LUA_SINGLE || showMTInfo == MT_LUA_SINGLE_BATCH || showMTInfo == MT_LUA_DUAL_EXPORT)) {
 			float pval = (showMTInfo == MT_LUA_DUAL_EXPORT) ? (float)luaExportSize / 1000.0f : (float)luaLockTime / 10.0f;
 			const char *pstr = (showMTInfo == MT_LUA_DUAL_EXPORT) ? "LUA-EXP-SIZE(MT): %2.1fK" : "LUA-SYNC-CPU(MT): %2.1f%%";
 			char buf[40];
 			SNPRINTF(buf, sizeof(buf), pstr, pval);
-			float4 warncol(pval >= 10.0f && (currentTime & 128) ?
+			float4 warncol(pval >= 10.0f && ((int)spring_tomsecs(currentTime) & 128) ?
 				0.5f : std::max(0.0f, std::min(pval / 5.0f, 1.0f)), std::max(0.0f, std::min(2.0f - pval / 5.0f, 1.0f)), 0.0f, 1.0f);
 			smallFont->SetColors(&warncol, NULL);
 			smallFont->glPrint(0.99f, 0.88f, 1.0f, font_options, buf);
 		}
-#endif
 
 		CPlayerRosterDrawer::Draw();
 
 		smallFont->End();
 	}
 
-#if defined(USE_GML) && GML_ENABLE_SIM
-	if (skipping)
+	if (GML::SimEnabled() && skipping)
 		DrawSkip(false);
-#endif
 
 	mouse->DrawCursor();
 
 	glEnable(GL_DEPTH_TEST);
 	glLoadIdentity();
 
-	unsigned start = SDL_GetTicks();
-	globalRendering->lastFrameTime = (float)(start - lastMoveUpdate)/1000.f;
-	lastMoveUpdate = start;
+	const spring_time start = spring_gettime();
+	globalRendering->lastFrameTime = spring_tomsecs(start - lastDrawFrameUpdate) / 1000.f;
+	lastDrawFrameUpdate = start;
 
 	videoCapturing->RenderFrame();
 
@@ -1316,7 +1351,7 @@ void CGame::StartPlaying()
 	playing = true;
 	GameSetupDrawer::Disable();
 	lastTick = clock();
-	lastframe = SDL_GetTicks();
+	lastframe = spring_gettime();
 
 	gu->startTime = gu->gameTime;
 	gu->myTeam = playerHandler->Player(gu->myPlayerNum)->team;
@@ -1384,10 +1419,12 @@ void CGame::StartPlaying()
 
 
 void CGame::SimFrame() {
+	ENTER_SYNCED_CODE();
+
 	ScopedTimer cputimer("Game::SimFrame", true); // SimFrame
 
 	good_fpu_control_registers("CGame::SimFrame");
-	lastFrameTime = SDL_GetTicks();
+	lastFrameTime = spring_gettime();
 
 	gs->frameNum++;
 
@@ -1438,9 +1475,11 @@ void CGame::SimFrame() {
 	teamHandler->GameFrame(gs->frameNum);
 	playerHandler->GameFrame(gs->frameNum);
 
-	lastUpdate = SDL_GetTicks();
+	lastSimFrameTime = spring_gettime();
 
 	DumpState(-1, -1, 1);
+
+	LEAVE_SYNCED_CODE();
 }
 
 
@@ -1611,7 +1650,11 @@ void CGame::DumpState(int newMinFrameNum, int newMaxFrameNum, int newFramePeriod
 			file << "map name: " << gameSetup->mapName << "\n";
 			file << "mod name: " << gameSetup->modName << "\n";
 			file << "minFrame: " << gMinFrameNum << ", maxFrame: " << gMaxFrameNum << "\n";
+			file << "randSeed: " << gs->GetRandSeed() << "\n";
+			file << "initSeed: " << gs->GetInitRandSeed() << "\n";
 		}
+
+		LOG("[DumpState] using dump-file \"%s\"", name.c_str());
 	}
 
 	if (file.bad() || !file.is_open()) { return; }
@@ -1631,7 +1674,7 @@ void CGame::DumpState(int newMinFrameNum, int newMaxFrameNum, int newFramePeriod
 	std::vector<LocalModelPiece*>::const_iterator piecesIt;
 	std::vector<CWeapon*>::const_iterator weaponsIt;
 
-	file << "frame: " << gs->frameNum << "\n";
+	file << "frame: " << gs->frameNum << ", seed: " << gs->GetRandSeed() << "\n";
 	file << "\tunits: " << units.size() << "\n";
 
 	#define DUMP_UNIT_DATA
@@ -1736,7 +1779,7 @@ void CGame::DumpState(int newMinFrameNum, int newMaxFrameNum, int newFramePeriod
 		file << "\t\t\t\tgoalPos: <" << goalPos.x << ", " << goalPos.y << ", " << goalPos.z << ">\n";
 		file << "\t\t\t\toldUpdatePos: <" << oldUpdatePos.x << ", " << oldUpdatePos.y << ", " << oldUpdatePos.z << ">\n";
 		file << "\t\t\t\toldSlowUpPos: <" << oldSlowUpPos.x << ", " << oldSlowUpPos.y << ", " << oldSlowUpPos.z << ">\n";
-		file << "\t\t\t\tmaxSpeed: " << amt->maxSpeed << ", maxWantedSpeed: " << amt->maxWantedSpeed << "\n";
+		file << "\t\t\t\tmaxSpeed: " << amt->GetMaxSpeed() << ", maxWantedSpeed: " << amt->GetMaxWantedSpeed() << "\n";
 		file << "\t\t\t\tprogressState: " << amt->progressState << "\n";
 		#endif
 	}
@@ -1981,7 +2024,7 @@ void CGame::StartSkip(int toFrame) {
 	gs->speedFactor     = speed;
 	gs->userSpeedFactor = speed;
 
-	skipLastDraw = SDL_GetTicks();
+	skipLastDraw = spring_gettime();
 
 	skipping = true;
 }
@@ -2193,8 +2236,10 @@ void CGame::ReColorTeams()
 
 bool CGame::HasLag() const
 {
-	unsigned timeNow = SDL_GetTicks();
-	if (!gs->paused && (timeNow > (lastFrameTime + (500.0f / gs->speedFactor)))) {
+	const spring_time timeNow = spring_gettime();
+	const float diffTime = spring_tomsecs(timeNow - lastFrameTime);
+
+	if (!gs->paused && (diffTime > (500.0f / gs->speedFactor))) {
 		return true;
 	} else {
 		return false;
@@ -2251,26 +2296,26 @@ void CGame::ActionReceived(const Action& action, int playerID)
 bool CGame::ActionPressed(unsigned int key, const Action& action, bool isRepeat)
 {
 	const IUnsyncedActionExecutor* executor = unsyncedGameCommands->GetActionExecutor(action.command);
-
 	if (executor != NULL) {
 		// an executor for that action was found
 		UnsyncedAction unsyncedAction(action, key, isRepeat);
 		executor->ExecuteAction(unsyncedAction);
-	} else {
-		static std::set<std::string> serverCommands = std::set<std::string>(commands, commands+numCommands);
-		if (serverCommands.find(action.command) != serverCommands.end())
-		{
-			CommandMessage pckt(action, gu->myPlayerNum);
-			net->Send(pckt.Pack());
-		}
-
-		if (!Console::Instance().ExecuteAction(action))
-		{
-			if (guihandler != NULL) // maybe a widget is interested?
-				guihandler->PushLayoutCommand(action.rawline, false);
-			return false;
-		}
+		return true; // XXX catch exceptions thrown in ExecuteAction to deside what to return here?
 	}
 
+	static std::set<std::string> serverCommands = std::set<std::string>(commands, commands+numCommands);
+	if (serverCommands.find(action.command) != serverCommands.end()) {
+		CommandMessage pckt(action, gu->myPlayerNum);
+		net->Send(pckt.Pack());
+		return true;
+	}
+
+	if (Console::Instance().ExecuteAction(action)) {
+		return true;
+	}
+
+	if (guihandler != NULL) // maybe a widget is interested?
+		guihandler->PushLayoutCommand(action.rawline, false);
+
 	return false;
 }
