@@ -2,18 +2,20 @@
 
 #include "GameParticipant.h"
 
-#include "Net/Connection.h"
-#include "BaseNetProtocol.h"
+#include "Sim/Misc/GlobalConstants.h"
+#include "System/Net/Connection.h"
+#include "System/BaseNetProtocol.h"
 
 GameParticipant::GameParticipant()
 : myState(UNCONNECTED)
 , lastFrameResponse(0)
 , speedControl(0)
-, luaDrawTime(0)
+, luaLockTime(0)
 , isLocal(false)
 , isReconn(false)
 , isMidgameJoin(false)
 {
+	linkData[MAX_AIS] = PlayerLinkData(false);
 }
 
 void GameParticipant::SendData(boost::shared_ptr<const netcode::RawPacket> packet)
@@ -25,6 +27,7 @@ void GameParticipant::SendData(boost::shared_ptr<const netcode::RawPacket> packe
 void GameParticipant::Connected(boost::shared_ptr<netcode::CConnection> _link, bool local)
 {
 	link = _link;
+	linkData[MAX_AIS].link.reset(new netcode::CLoopbackConnection());
 	isLocal = local;
 	myState = CONNECTED;
 }
@@ -34,8 +37,10 @@ void GameParticipant::Kill(const std::string& reason)
 	if (link)
 	{
 		link->SendData(CBaseNetProtocol::Get().SendQuit(reason));
+		link->Close();
 		link.reset();
 	}
+	linkData[MAX_AIS].link.reset();
 #ifdef SYNCCHECK
 	syncResponse.clear();
 #endif
