@@ -1,14 +1,13 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
 #include <cctype>
 
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 #include "KeyCodes.h"
 #include "SDL_keysym.h"
-#include "LogOutput.h"
-#include "Util.h"
+#include "System/Log/ILog.h"
+#include "System/Util.h"
 
 
 CKeyCodes* keyCodes = NULL;
@@ -245,7 +244,7 @@ void CKeyCodes::PrintNameToCode() const
 {
 	std::map<std::string, int>::const_iterator it;
 	for (it = nameToCode.begin(); it != nameToCode.end(); ++it) {
-		logOutput.Print("KEYNAME: %13s = 0x%03X\n", it->first.c_str(), it->second);
+		LOG("KEYNAME: %13s = 0x%03X", it->first.c_str(), it->second);
 	}
 }
 
@@ -254,7 +253,7 @@ void CKeyCodes::PrintCodeToName() const
 {
 	std::map<int, std::string>::const_iterator it;
 	for (it = codeToName.begin(); it != codeToName.end(); ++it) {
-		logOutput.Print("KEYCODE: 0x%03X = '%s'\n", it->first, it->second.c_str());
+		LOG("KEYCODE: 0x%03X = '%s'", it->first, it->second.c_str());
 	}
 }
 
