@@ -1,11 +1,10 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 #include "LuaCallInCheck.h"
 #include "LuaInclude.h"
-#include "LogOutput.h"
+#include "System/Log/ILog.h"
 
 
 /******************************************************************************/
@@ -23,8 +22,9 @@ LuaCallInCheck::~LuaCallInCheck()
 {
 	const int endTop = lua_gettop(L);
 	if (startTop != endTop) {
-		logOutput.Print("LuaCallInCheck mismatch for %s():  start = %i,  end = %i",
-		                funcName, startTop, endTop);
+		LOG_L(L_WARNING,
+				"LuaCallInCheck mismatch for %s():  start = %i,  end = %i",
+				funcName, startTop, endTop);
 	}
 }
 
