@@ -3,6 +3,8 @@
 #ifndef LUA_CALL_IN_CHECK_H
 #define LUA_CALL_IN_CHECK_H
 
+#include "LuaEventBatch.h"
+
 struct lua_State;
 
 
@@ -17,11 +19,10 @@ class LuaCallInCheck {
 		const char* funcName;
 };
 
-
 #if DEBUG_LUA
-#  define LUA_CALL_IN_CHECK(L) LuaCallInCheck ciCheck((L), __FUNCTION__);
+#  define LUA_CALL_IN_CHECK(L) SELECT_LUA_STATE(); LuaCallInCheck ciCheck((L), __FUNCTION__)
 #else
-#  define LUA_CALL_IN_CHECK(L)
+#  define LUA_CALL_IN_CHECK(L) SELECT_LUA_STATE()
 #endif
 
 #ifdef USE_GML // hack to add some degree of thread safety to LUA
@@ -30,9 +31,9 @@ class LuaCallInCheck {
 #	if GML_ENABLE_SIM
 #		undef LUA_CALL_IN_CHECK
 #		if DEBUG_LUA
-#			define LUA_CALL_IN_CHECK(L) GML_RECMUTEX_LOCK(lua); GML_CALL_DEBUGGER(); LuaCallInCheck ciCheck((L), __FUNCTION__);
+#			define LUA_CALL_IN_CHECK(L) SELECT_LUA_STATE(); GML_DRCMUTEX_LOCK(lua); GML_CALL_DEBUGGER(); LuaCallInCheck ciCheck((L), __FUNCTION__);
 #		else
-#			define LUA_CALL_IN_CHECK(L) GML_RECMUTEX_LOCK(lua); GML_CALL_DEBUGGER();
+#			define LUA_CALL_IN_CHECK(L) SELECT_LUA_STATE(); GML_DRCMUTEX_LOCK(lua); GML_CALL_DEBUGGER();
 #		endif
 #	endif
 #endif
