@@ -5,8 +5,6 @@
 
 #include <map>
 #include <string>
-using std::map;
-using std::string;
 
 
 enum DataType {
@@ -39,7 +37,7 @@ struct DataElement {
 };
 
 
-typedef map<string, DataElement> ParamMap;
+typedef std::map<std::string, DataElement> ParamMap;
 
 
 /* This is unused and does not compile on GCC 4.3 -- tvo 9/9/2007
@@ -76,4 +74,17 @@ template<> static DataType GetDataType(string) { return STRING_TYPE; }
 	paramMap[lua] = DataElement(FUNCTION_TYPE, ADDRESS(cpp) - start, func)
 
 
+
+
+#if (LUA_VERSION_NUM < 500)
+#  define LUA_OPEN_LIB(L, lib) lib(L)
+#else
+#  define LUA_OPEN_LIB(L, lib) \
+     lua_pushcfunction((L), lib); \
+     lua_pcall((L), 0, 0, 0);
+#endif
+
+
+
+
 #endif // LUA_DEFS_H
