@@ -3,16 +3,12 @@
 #ifndef LUA_PARSER_H
 #define LUA_PARSER_H
 
+#include "System/FileSystem/VFSModes.h"
+
 #include <string>
 #include <vector>
 #include <map>
 #include <set>
-using std::string;
-using std::vector;
-using std::map;
-using std::set;
-
-#include "FileSystem/VFSModes.h"
 
 class float3;
 struct float4;
@@ -20,6 +16,11 @@ class LuaTable;
 class LuaParser;
 struct lua_State;
 
+using std::string;
+using std::vector;
+using std::map;
+using std::set;
+
 
 /******************************************************************************/
 
@@ -56,8 +57,15 @@ class LuaTable {
 		bool KeyExists(int key) const;
 		bool KeyExists(const string& key) const;
 
-		int GetType(int key) const;
-		int GetType(const string& key) const;
+		enum DataType {
+			NIL     = -1,
+			NUMBER  = 1,
+			STRING  = 2,
+			BOOLEAN = 3,
+			TABLE   = 4
+		};
+		DataType GetType(int key) const;
+		DataType GetType(const string& key) const;
 
 		// numeric keys
 		int    GetInt(int key, int def) const;
@@ -75,21 +83,6 @@ class LuaTable {
 		float4 GetFloat4(const string& key, const float4& def) const;
 		string GetString(const string& key, const string& def) const;
 
-		/* not having these makes for better code, imo
-		LuaTable operator[](int key)           const { return SubTable(key); }
-		LuaTable operator[](const string& key) const { return SubTable(key); }
-		int    operator()(int key, int def)           const { return GetInt(key, def);    }
-		bool   operator()(int key, bool def)          const { return GetBool(key, def);   }
-		float  operator()(int key, float def)         const { return GetFloat(key, def);  }
-		float3 operator()(int key, const float3& def) const { return GetFloat3(key, def); }
-		string operator()(int key, const string& def) const { return GetString(key, def); }
-		int    operator()(const string& key, int def)           const { return GetInt(key, def);    }
-		bool   operator()(const string& key, bool def)          const { return GetBool(key, def);   }
-		float  operator()(const string& key, float def)         const { return GetFloat(key, def);  }
-		float3 operator()(const string& key, const float3& def) const { return GetFloat3(key, def); }
-		string operator()(const string& key, const string& def) const { return GetString(key, def); }
-		*/
-
 	private:
 		LuaTable(LuaParser* parser); // for LuaParser::GetRoot()
 
