@@ -51,6 +51,8 @@ const int* CLuaRules::currentCobArgs = NULL;
 
 void CLuaRules::LoadHandler()
 {
+	//FIXME GML: this needs a mutex!!!
+
 	if (luaRules) {
 		return;
 	}
@@ -65,6 +67,7 @@ void CLuaRules::LoadHandler()
 
 void CLuaRules::FreeHandler()
 {
+	//FIXME GML: this needs a mutex!!!
 	delete luaRules;
 }
 
@@ -244,23 +247,20 @@ static void PushUnitAndCommand(lua_State* L, const CUnit* unit, const Command& c
 
 bool CLuaRules::CommandFallback(const CUnit* unit, const Command& cmd)
 {
-	if (!haveCommandFallback) {
+	if (!haveCommandFallback)
 		return true; // the call is not defined
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 9);
 	static const LuaHashString cmdStr("CommandFallback");
-	if (!cmdStr.GetGlobalFunc(L)) {
+	if (!cmdStr.GetGlobalFunc(L))
 		return true; // the call is not defined
-	}
 
 	PushUnitAndCommand(L, unit, cmd);
 
 	// call the function
-	if (!RunCallIn(cmdStr, 7, 1)) {
+	if (!RunCallIn(cmdStr, 7, 1))
 		return true;
-	}
 
 	// get the results
 	if (!lua_isboolean(L, -1)) {
@@ -279,25 +279,22 @@ bool CLuaRules::CommandFallback(const CUnit* unit, const Command& cmd)
 
 bool CLuaRules::AllowCommand(const CUnit* unit, const Command& cmd, bool fromSynced)
 {
-	if (!haveAllowCommand) {
+	if (!haveAllowCommand)
 		return true; // the call is not defined
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 10);
 	static const LuaHashString cmdStr("AllowCommand");
-	if (!cmdStr.GetGlobalFunc(L)) {
+	if (!cmdStr.GetGlobalFunc(L))
 		return true; // the call is not defined
-	}
 
 	PushUnitAndCommand(L, unit, cmd);
 
 	lua_pushboolean(L, fromSynced);
 
 	// call the function
-	if (!RunCallIn(cmdStr, 8, 1)) {
+	if (!RunCallIn(cmdStr, 8, 1))
 		return true;
-	}
 
 	// get the results
 	if (!lua_isboolean(L, -1)) {
@@ -314,16 +311,14 @@ bool CLuaRules::AllowCommand(const CUnit* unit, const Command& cmd, bool fromSyn
 bool CLuaRules::AllowUnitCreation(const UnitDef* unitDef,
                                   const CUnit* builder, const float3* pos)
 {
-	if (!haveAllowUnitCreation) {
+	if (!haveAllowUnitCreation)
 		return true; // the call is not defined
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 8);
 	static const LuaHashString cmdStr("AllowUnitCreation");
-	if (!cmdStr.GetGlobalFunc(L)) {
+	if (!cmdStr.GetGlobalFunc(L))
 		return true; // the call is not defined
-	}
 
 	lua_pushnumber(L, unitDef->id);
 	lua_pushnumber(L, builder->id);
@@ -335,9 +330,8 @@ bool CLuaRules::AllowUnitCreation(const UnitDef* unitDef,
 	}
 
 	// call the function
-	if (!RunCallIn(cmdStr, pos ? 6 : 3, 1)) {
+	if (!RunCallIn(cmdStr, pos ? 6 : 3, 1))
 		return true;
-	}
 
 	// get the results
 	if (!lua_isboolean(L, -1)) {
@@ -354,16 +348,14 @@ bool CLuaRules::AllowUnitCreation(const UnitDef* unitDef,
 
 bool CLuaRules::AllowUnitTransfer(const CUnit* unit, int newTeam, bool capture)
 {
-	if (!haveAllowUnitTransfer) {
+	if (!haveAllowUnitTransfer)
 		return true; // the call is not defined
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 7);
 	static const LuaHashString cmdStr("AllowUnitTransfer");
-	if (!cmdStr.GetGlobalFunc(L)) {
+	if (!cmdStr.GetGlobalFunc(L))
 		return true; // the call is not defined
-	}
 
 	lua_pushnumber(L, unit->id);
 	lua_pushnumber(L, unit->unitDef->id);
@@ -372,9 +364,8 @@ bool CLuaRules::AllowUnitTransfer(const CUnit* unit, int newTeam, bool capture)
 	lua_pushboolean(L, capture);
 
 	// call the function
-	if (!RunCallIn(cmdStr, 5, 1)) {
+	if (!RunCallIn(cmdStr, 5, 1))
 		return true;
-	}
 
 	// get the results
 	if (!lua_isboolean(L, -1)) {
@@ -392,16 +383,14 @@ bool CLuaRules::AllowUnitTransfer(const CUnit* unit, int newTeam, bool capture)
 bool CLuaRules::AllowUnitBuildStep(const CUnit* builder,
                                    const CUnit* unit, float part)
 {
-	if (!haveAllowUnitBuildStep) {
+	if (!haveAllowUnitBuildStep)
 		return true; // the call is not defined
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 7);
 	static const LuaHashString cmdStr("AllowUnitBuildStep");
-	if (!cmdStr.GetGlobalFunc(L)) {
+	if (!cmdStr.GetGlobalFunc(L))
 		return true; // the call is not defined
-	}
 
 	lua_pushnumber(L, builder->id);
 	lua_pushnumber(L, builder->team);
@@ -410,9 +399,8 @@ bool CLuaRules::AllowUnitBuildStep(const CUnit* builder,
 	lua_pushnumber(L, part);
 
 	// call the function
-	if (!RunCallIn(cmdStr, 5, 1)) {
+	if (!RunCallIn(cmdStr, 5, 1))
 		return true;
-	}
 
 	// get the results
 	if (!lua_isboolean(L, -1)) {
@@ -430,16 +418,14 @@ bool CLuaRules::AllowUnitBuildStep(const CUnit* builder,
 bool CLuaRules::AllowFeatureCreation(const FeatureDef* featureDef,
                                      int teamID, const float3& pos)
 {
-	if (!haveAllowFeatureCreation) {
+	if (!haveAllowFeatureCreation)
 		return true; // the call is not defined
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 7);
 	static const LuaHashString cmdStr("AllowFeatureCreation");
-	if (!cmdStr.GetGlobalFunc(L)) {
+	if (!cmdStr.GetGlobalFunc(L))
 		return true; // the call is not defined
-	}
 
 	lua_pushnumber(L, featureDef->id);
 	lua_pushnumber(L, teamID);
@@ -448,9 +434,8 @@ bool CLuaRules::AllowFeatureCreation(const FeatureDef* featureDef,
 	lua_pushnumber(L, pos.z);
 
 	// call the function
-	if (!RunCallIn(cmdStr, 5, 1)) {
+	if (!RunCallIn(cmdStr, 5, 1))
 		return true;
-	}
 
 	// get the results
 	if (!lua_isboolean(L, -1)) {
@@ -468,16 +453,14 @@ bool CLuaRules::AllowFeatureCreation(const FeatureDef* featureDef,
 bool CLuaRules::AllowFeatureBuildStep(const CUnit* builder,
                                       const CFeature* feature, float part)
 {
-	if (!haveAllowFeatureBuildStep) {
+	if (!haveAllowFeatureBuildStep)
 		return true; // the call is not defined
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 7);
 	static const LuaHashString cmdStr("AllowFeatureBuildStep");
-	if (!cmdStr.GetGlobalFunc(L)) {
+	if (!cmdStr.GetGlobalFunc(L))
 		return true; // the call is not defined
-	}
 
 	lua_pushnumber(L, builder->id);
 	lua_pushnumber(L, builder->team);
@@ -486,9 +469,8 @@ bool CLuaRules::AllowFeatureBuildStep(const CUnit* builder,
 	lua_pushnumber(L, part);
 
 	// call the function
-	if (!RunCallIn(cmdStr, 5, 1)) {
+	if (!RunCallIn(cmdStr, 5, 1))
 		return true;
-	}
 
 	// get the results
 	if (!lua_isboolean(L, -1)) {
@@ -505,25 +487,22 @@ bool CLuaRules::AllowFeatureBuildStep(const CUnit* builder,
 
 bool CLuaRules::AllowResourceLevel(int teamID, const string& type, float level)
 {
-	if (!haveAllowResourceLevel) {
+	if (!haveAllowResourceLevel)
 		return true; // the call is not defined
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 5);
 	static const LuaHashString cmdStr("AllowResourceLevel");
-	if (!cmdStr.GetGlobalFunc(L)) {
+	if (!cmdStr.GetGlobalFunc(L))
 		return true; // the call is not defined
-	}
 
 	lua_pushnumber(L, teamID);
 	lua_pushsstring(L, type);
 	lua_pushnumber(L, level);
 
 	// call the function
-	if (!RunCallIn(cmdStr, 3, 1)) {
+	if (!RunCallIn(cmdStr, 3, 1))
 		return true;
-	}
 
 	// get the results
 	if (!lua_isboolean(L, -1)) {
@@ -541,16 +520,14 @@ bool CLuaRules::AllowResourceLevel(int teamID, const string& type, float level)
 bool CLuaRules::AllowResourceTransfer(int oldTeam, int newTeam,
                                       const string& type, float amount)
 {
-	if (!haveAllowResourceTransfer) {
+	if (!haveAllowResourceTransfer)
 		return true; // the call is not defined
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 6);
 	static const LuaHashString cmdStr("AllowResourceTransfer");
-	if (!cmdStr.GetGlobalFunc(L)) {
+	if (!cmdStr.GetGlobalFunc(L))
 		return true; // the call is not defined
-	}
 
 	lua_pushnumber(L, oldTeam);
 	lua_pushnumber(L, newTeam);
@@ -558,9 +535,8 @@ bool CLuaRules::AllowResourceTransfer(int oldTeam, int newTeam,
 	lua_pushnumber(L, amount);
 
 	// call the function
-	if (!RunCallIn(cmdStr, 4, 1)) {
+	if (!RunCallIn(cmdStr, 4, 1))
 		return true;
-	}
 
 	// get the results
 	if (!lua_isboolean(L, -1)) {
@@ -577,16 +553,14 @@ bool CLuaRules::AllowResourceTransfer(int oldTeam, int newTeam,
 
 bool CLuaRules::AllowDirectUnitControl(int playerID, const CUnit* unit)
 {
-	if (!haveAllowDirectUnitControl) {
+	if (!haveAllowDirectUnitControl)
 		return true; // the call is not defined
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 6);
 	static const LuaHashString cmdStr("AllowDirectUnitControl");
-	if (!cmdStr.GetGlobalFunc(L)) {
+	if (!cmdStr.GetGlobalFunc(L))
 		return true; // the call is not defined
-	}
 
 	lua_pushnumber(L, unit->id);
 	lua_pushnumber(L, unit->unitDef->id);
@@ -594,9 +568,8 @@ bool CLuaRules::AllowDirectUnitControl(int playerID, const CUnit* unit)
 	lua_pushnumber(L, playerID);
 
 	// call the function
-	if (!RunCallIn(cmdStr, 4, 1)) {
+	if (!RunCallIn(cmdStr, 4, 1))
 		return true;
-	}
 
 	// get the results
 	if (!lua_isboolean(L, -1)) {
@@ -613,16 +586,14 @@ bool CLuaRules::AllowDirectUnitControl(int playerID, const CUnit* unit)
 
 bool CLuaRules::AllowStartPosition(int playerID, const float3& pos)
 {
-	if (!haveAllowStartPosition) {
+	if (!haveAllowStartPosition)
 		return true; // the call is not defined
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 9);
 	static const LuaHashString cmdStr("AllowStartPosition");
-	if (!cmdStr.GetGlobalFunc(L)) {
+	if (!cmdStr.GetGlobalFunc(L))
 		return true; // the call is not defined
-	}
 
 	// push the start position and playerID
 	lua_pushnumber(L, pos.x);
@@ -631,9 +602,8 @@ bool CLuaRules::AllowStartPosition(int playerID, const float3& pos)
 	lua_pushnumber(L, playerID);
 
 	// call the function
-	if (!RunCallIn(cmdStr, 4, 1)) {
+	if (!RunCallIn(cmdStr, 4, 1))
 		return true;
-	}
 
 	// get the results
 	if (!lua_isboolean(L, -1)) {
@@ -649,16 +619,14 @@ bool CLuaRules::AllowStartPosition(int playerID, const float3& pos)
 
 bool CLuaRules::MoveCtrlNotify(const CUnit* unit, int data)
 {
-	if (!haveMoveCtrlNotify) {
+	if (!haveMoveCtrlNotify)
 		return false; // the call is not defined
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 6);
 	static const LuaHashString cmdStr("MoveCtrlNotify");
-	if (!cmdStr.GetGlobalFunc(L)) {
+	if (!cmdStr.GetGlobalFunc(L))
 		return false; // the call is not defined
-	}
 
 	// push the unit info
 	lua_pushnumber(L, unit->id);
@@ -667,9 +635,8 @@ bool CLuaRules::MoveCtrlNotify(const CUnit* unit, int data)
 	lua_pushnumber(L, data);
 
 	// call the function
-	if (!RunCallIn(cmdStr, 4, 1)) {
+	if (!RunCallIn(cmdStr, 4, 1))
 		return false;
-	}
 
 	// get the results
 	if (!lua_isboolean(L, -1)) {
@@ -687,16 +654,14 @@ bool CLuaRules::MoveCtrlNotify(const CUnit* unit, int data)
 
 bool CLuaRules::TerraformComplete(const CUnit* unit, const CUnit* build)
 {
-	if (!haveTerraformComplete) {
+	if (!haveTerraformComplete)
 		return false; // the call is not defined
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 8);
 	static const LuaHashString cmdStr("TerraformComplete");
-	if (!cmdStr.GetGlobalFunc(L)) {
+	if (!cmdStr.GetGlobalFunc(L))
 		return false; // the call is not defined
-	}
 
 	// push the unit info
 	lua_pushnumber(L, unit->id);
@@ -709,9 +674,8 @@ bool CLuaRules::TerraformComplete(const CUnit* unit, const CUnit* build)
 	lua_pushnumber(L, build->team);
 
 	// call the function
-	if (!RunCallIn(cmdStr, 6, 1)) {
+	if (!RunCallIn(cmdStr, 6, 1))
 		return false;
-	}
 
 	// get the results
 	if (!lua_isboolean(L, -1)) {
@@ -740,19 +704,18 @@ bool CLuaRules::UnitPreDamaged(const CUnit* unit, const CUnit* attacker,
                              float damage, int weaponID, bool paralyzer,
                              float* newDamage, float* impulseMult)
 {
-	if (!haveUnitPreDamaged) {
+	if (!haveUnitPreDamaged)
 		return false;
-	}
 
 	LUA_CALL_IN_CHECK(L);
-	lua_checkstack(L, 11);
+	lua_checkstack(L, 9 + 4);
 
 	const int errfunc = SetupTraceback(L);
 	static const LuaHashString cmdStr("UnitPreDamaged");
 
 	if (!cmdStr.GetGlobalFunc(L)) {
-		// remove error handler
-		if (errfunc) { lua_pop(L, 1); }
+		if (errfunc) // remove error handler
+			lua_pop(L, 1);
 		return false; // the call is not defined
 	}
 
@@ -774,7 +737,10 @@ bool CLuaRules::UnitPreDamaged(const CUnit* unit, const CUnit* attacker,
 	}
 
 	// call the routine
-	RunCallInTraceback(cmdStr, argCount, 2, errfunc);
+	const bool success = RunCallInTraceback(cmdStr, argCount, 2, errfunc);
+
+	if (!success)
+		return false;
 
 	if (newDamage && lua_isnumber(L, -2)) {
 		*newDamage = lua_tonumber(L, -2);
@@ -804,23 +770,20 @@ bool CLuaRules::ShieldPreDamaged(
 	const CUnit* shieldCarrier,
 	bool bounceProjectile
 ) {
-	if (!haveShieldPreDamaged) {
+	if (!haveShieldPreDamaged)
 		return false;
-	}
 
 	LUA_CALL_IN_CHECK(L);
-	lua_checkstack(L, 5 + 1);
+	lua_checkstack(L, 5 + 3);
 
 	const int errfunc(SetupTraceback(L));
 	static const LuaHashString cmdStr("ShieldPreDamaged");
 
-	bool ret = false;
-
 	if (!cmdStr.GetGlobalFunc(L)) {
-		if (errfunc) { lua_pop(L, 1); }
-
+		if (errfunc)
+			lua_pop(L, 1);
 		// undefined call-in
-		return ret;
+		return false;
 	}
 
 	// push the call-in arguments
@@ -831,10 +794,13 @@ bool CLuaRules::ShieldPreDamaged(
 	lua_pushboolean(L, bounceProjectile);
 
 	// call the routine
-	RunCallInTraceback(cmdStr, 5, 1, errfunc);
+	const bool success = RunCallInTraceback(cmdStr, 5, 1, errfunc);
+
+	if (!success)
+		return false;
 
 	// pop the return-value; must be true or false
-	ret = (lua_isboolean(L, -1) && lua_toboolean(L, -1));
+	const bool ret = (lua_isboolean(L, -1) && lua_toboolean(L, -1));
 	lua_pop(L, -1);
 
 	return ret;
@@ -846,9 +812,8 @@ bool CLuaRules::ShieldPreDamaged(
 
 int CLuaRules::AllowWeaponTargetCheck(unsigned int attackerID, unsigned int attackerWeaponNum, unsigned int attackerWeaponDefID)
 {
-	if (!haveAllowWeaponTargetCheck) {
+	if (!haveAllowWeaponTargetCheck)
 		return -1;
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 3 + 1);
@@ -859,7 +824,8 @@ int CLuaRules::AllowWeaponTargetCheck(unsigned int attackerID, unsigned int atta
 	int ret = -1;
 
 	if (!cmdStr.GetGlobalFunc(L)) {
-		if (errfunc) { lua_pop(L, 1); }
+		if (errfunc)
+			lua_pop(L, 1);
 		return ret;
 	}
 
@@ -867,7 +833,10 @@ int CLuaRules::AllowWeaponTargetCheck(unsigned int attackerID, unsigned int atta
 	lua_pushnumber(L, attackerWeaponNum);
 	lua_pushnumber(L, attackerWeaponDefID);
 
-	RunCallInTraceback(cmdStr, 3, 1, errfunc);
+	const bool success = RunCallInTraceback(cmdStr, 3, 1, errfunc);
+
+	if (!success)
+		return ret;
 
 	ret = (lua_isboolean(L, -1) && lua_toboolean(L, -1))? 1: 0;
 	lua_pop(L, -1);
@@ -882,9 +851,8 @@ int CLuaRules::AllowWeaponTarget(
 	unsigned int attackerWeaponDefID,
 	float* targetPriority)
 {
-	if (!haveAllowWeaponTarget) {
+	if (!haveAllowWeaponTarget)
 		return -1;
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 4 + 2);
@@ -895,7 +863,8 @@ int CLuaRules::AllowWeaponTarget(
 	int ret = -1;
 
 	if (!cmdStr.GetGlobalFunc(L)) {
-		if (errfunc) { lua_pop(L, 1); }
+		if (errfunc)
+			lua_pop(L, 1);
 		return ret;
 	}
 
@@ -904,7 +873,10 @@ int CLuaRules::AllowWeaponTarget(
 	lua_pushnumber(L, attackerWeaponNum);
 	lua_pushnumber(L, attackerWeaponDefID);
 
-	RunCallInTraceback(cmdStr, 4, 2, errfunc);
+	const bool success = RunCallInTraceback(cmdStr, 4, 2, errfunc);
+
+	if (!success)
+		return ret;
 
 	ret = (lua_isboolean(L, -2) && lua_toboolean(L, -2))? 1: 0;
 
@@ -922,16 +894,14 @@ int CLuaRules::AllowWeaponTarget(
 
 bool CLuaRules::DrawUnit(int unitID)
 {
-	if (!haveDrawUnit) {
+	if (!haveDrawUnit)
 		return false;
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 4);
 	static const LuaHashString cmdStr("DrawUnit");
-	if (!cmdStr.GetRegistryFunc(L)) {
+	if (!cmdStr.GetRegistryFunc(L))
 		return false;
-	}
 
 	const bool oldGLState = LuaOpenGL::IsDrawingEnabled();
 	LuaOpenGL::SetDrawingEnabled(true);
@@ -943,9 +913,8 @@ bool CLuaRules::DrawUnit(int unitID)
 
 	LuaOpenGL::SetDrawingEnabled(oldGLState);
 
-	if (!success) {
+	if (!success)
 		return false;
-	}
 
 	if (!lua_isboolean(L, -1)) {
 		LOG_L(L_WARNING, "%s() bad return value", cmdStr.GetString().c_str());
@@ -960,16 +929,14 @@ bool CLuaRules::DrawUnit(int unitID)
 
 bool CLuaRules::DrawFeature(int featureID)
 {
-	if (!haveDrawFeature) {
+	if (!haveDrawFeature)
 		return false;
-	}
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 4);
 	static const LuaHashString cmdStr("DrawFeature");
-	if (!cmdStr.GetRegistryFunc(L)) {
+	if (!cmdStr.GetRegistryFunc(L))
 		return false;
-	}
 
 	const bool oldGLState = LuaOpenGL::IsDrawingEnabled();
 	LuaOpenGL::SetDrawingEnabled(true);
@@ -981,9 +948,8 @@ bool CLuaRules::DrawFeature(int featureID)
 
 	LuaOpenGL::SetDrawingEnabled(oldGLState);
 
-	if (!success) {
+	if (!success)
 		return false;
-	}
 
 	if (!lua_isboolean(L, -1)) {
 		LOG_L(L_WARNING, "%s() bad return value", cmdStr.GetString().c_str());
