@@ -1,11 +1,10 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 #include "LuaTextures.h"
 
-#include "Util.h"
+#include "System/Util.h"
 
 
 /******************************************************************************/
