@@ -589,6 +589,14 @@ TYPE_MODEL_FUNC(ModelMidz,   relMidPos.z);
 TYPE_MODEL_FUNC(ModelMaxz,   maxs.z);
 
 
+
+static int ReturnFalse(lua_State* L, const void* data)
+{
+	lua_pushboolean(L, false);
+	return 1;
+}
+
+
 /******************************************************************************/
 /******************************************************************************/
 
@@ -628,7 +636,7 @@ ADD_BOOL("canAttackWater",  canAttackWater); // CUSTOM
 	ADD_FUNCTION("stockpileWeaponDef", ud.stockpileWeaponDef, WeaponDefToID);
 	ADD_FUNCTION("iconType",           ud.iconType,           SafeIconType);
 
-	ADD_FUNCTION("type",         ud, GetTypeString); // NOTE: deprecated, remove after 0.83.*
+	ADD_FUNCTION("type",         ud, GetTypeString); // backward compability (TODO: find a way to print a warning when used!)
 	ADD_FUNCTION("isBuilding",   ud, IsBuildingUnit);
 	ADD_FUNCTION("isFactory",    ud, IsFactoryUnit);
 	ADD_FUNCTION("isFighter",    ud, IsFighterUnit);
@@ -717,7 +725,7 @@ ADD_BOOL("canAttackWater",  canAttackWater); // CUSTOM
 
 	ADD_FLOAT("mass", ud.mass);
 
-	ADD_FLOAT("maxSlope",      ud.maxHeightDif); // NOTE: deprecated, remove after 0.83.*
+	ADD_FLOAT("maxSlope",      ud.maxHeightDif); // backward compability (TODO: find a way to print a warning when used!)
 	ADD_FLOAT("maxHeightDif",  ud.maxHeightDif);
 	ADD_FLOAT("minWaterDepth", ud.minWaterDepth);
 	ADD_FLOAT("waterline",     ud.waterline);
@@ -751,12 +759,13 @@ ADD_BOOL("canAttackWater",  canAttackWater); // CUSTOM
 	ADD_FLOAT("terraformSpeed", ud.terraformSpeed);
 
 	ADD_BOOL("canSubmerge",       ud.canSubmerge);
+	ADD_BOOL("floatOnWater",      ud.floatOnWater);
+	ADD_BOOL("floater",           ud.floatOnWater);  // backward compability (TODO: find a way to print a warning when used!)
 	ADD_BOOL("canFly",            ud.canfly);
 	ADD_BOOL("canMove",           ud.canmove);
-	ADD_BOOL("canHover",          ud.canhover);
-	ADD_BOOL("floater",           ud.floater);
+	ADD_BOOL("canHover",          ud.canHover);
+	ADD_BOOL("isBuilder",         ud.builder);  // backward compability (TODO: find a way to print a warning when used!)
 	ADD_BOOL("builder",           ud.builder);
-	ADD_BOOL("isBuilder",         ud.builder); // NOTE: deprecated, remove after 0.83.*
 	ADD_BOOL("onOffable",         ud.onoffable);
 	ADD_BOOL("activateWhenBuilt", ud.activateWhenBuilt);
 
@@ -764,7 +773,7 @@ ADD_BOOL("canAttackWater",  canAttackWater); // CUSTOM
 	ADD_BOOL("capturable",  ud.capturable);
 	ADD_BOOL("repairable",  ud.repairable);
 
-	ADD_BOOL("canDGun",               ud.canManualFire); // NOTE: deprecated, remove after 0.83.*
+	ADD_BOOL("canDGun",               ud.canManualFire);  // backward compability (TODO: find a way to print a warning when used!)
 	ADD_BOOL("canManualFire",         ud.canManualFire);
 	ADD_BOOL("canCloak",              ud.canCloak);
 	ADD_BOOL("canRestore",            ud.canRestore);
@@ -781,7 +790,7 @@ ADD_BOOL("canAttackWater",  canAttackWater); // CUSTOM
 	ADD_BOOL("canCapture",            ud.canCapture);
 	ADD_BOOL("canResurrect",          ud.canResurrect);
 	ADD_BOOL("canLoopbackAttack",     ud.canLoopbackAttack);
-	ADD_BOOL("canCrash",              ud.canLoopbackAttack); // NOTE: deprecated, remove after 0.83.*
+	ADD_BOOL("canCrash",              ud.canLoopbackAttack);  // backward compability (TODO: find a way to print a warning when used!)
 	ADD_BOOL("canFireControl",        ud.canFireControl);
 	ADD_INT( "fireState",             ud.fireState);
 	ADD_INT( "moveState",             ud.moveState);
@@ -863,7 +872,7 @@ ADD_BOOL("canAttackWater",  canAttackWater); // CUSTOM
 	ADD_BOOL("needGeo",   ud.needGeo);
 	ADD_BOOL("isFeature", ud.isFeature);
 
-	ADD_BOOL("isCommander", ud.isCommander);
+	ADD_FUNCTION("isCommander", ud, ReturnFalse);  // backward compability (TODO: find a way to print a warning when used!)
 
 	ADD_BOOL("hideDamage",     ud.hideDamage);
 	ADD_BOOL("showPlayerName", ud.showPlayerName);
