@@ -1,30 +1,45 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
+#include "System/Platform/Win/win32.h"
 
 #include <set>
 #include <cctype>
 #include <zlib.h>
 #include <boost/cstdint.hpp>
+#include <string.h>
 
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 #include "LuaUtils.h"
 
-#include "LogOutput.h"
-#include "Util.h"
+#include "System/Log/ILog.h"
+#include "System/Util.h"
+#include "LuaConfig.h"
+#include <boost/thread/recursive_mutex.hpp>
 
-
-static       int depth = 0;
 static const int maxDepth = 256;
+int backupSize = 0;
 
 
+boost::recursive_mutex luaprimmutex, luasecmutex;
+
+boost::recursive_mutex* getLuaMutex(bool userMode, bool primary) {
+#if (LUA_MT_OPT & LUA_MUTEX)
+	if(userMode)
+		return new boost::recursive_mutex();
+	else // LuaGaia & LuaRules will share mutexes to avoid deadlocks during XCalls etc.
+		return primary ? &luaprimmutex : &luasecmutex;
+#else
+		return &luaprimmutex;
+#endif
+}
+
 /******************************************************************************/
 /******************************************************************************/
 
 
-static bool CopyPushData(lua_State* dst, lua_State* src, int index);
-static bool CopyPushTable(lua_State* dst, lua_State* src, int index);
+static bool CopyPushData(lua_State* dst, lua_State* src, int index, int depth);
+static bool CopyPushTable(lua_State* dst, lua_State* src, int index, int depth);
 
 
 static inline int PosLuaIndex(lua_State* src, int index)
@@ -37,7 +52,7 @@ static inline int PosLuaIndex(lua_State* src, int index)
 }
 
 
-static bool CopyPushData(lua_State* dst, lua_State* src, int index)
+static bool CopyPushData(lua_State* dst, lua_State* src, int index, int depth)
 {
 	const int type = lua_type(src, index);
 	switch (type) {
@@ -56,7 +71,7 @@ static bool CopyPushData(lua_State* dst, lua_State* src, int index)
 			break;
 		}
 		case LUA_TTABLE: {
-			CopyPushTable(dst, src, index);
+			CopyPushTable(dst, src, index, depth);
 			break;
 		}
 		default: {
@@ -68,22 +83,20 @@ static bool CopyPushData(lua_State* dst, lua_State* src, int index)
 }
 
 
-static bool CopyPushTable(lua_State* dst, lua_State* src, int index)
+static bool CopyPushTable(lua_State* dst, lua_State* src, int index, int depth)
 {
-	if (depth > maxDepth) {
+	if (depth++ > maxDepth) {
 		lua_pushnil(dst); // push something
 		return false;
 	}
 
-	depth++;
 	lua_newtable(dst);
 	const int table = PosLuaIndex(src, index);
 	for (lua_pushnil(src); lua_next(src, table) != 0; lua_pop(src, 1)) {
-		CopyPushData(dst, src, -2); // copy the key
-		CopyPushData(dst, src, -1); // copy the value
+		CopyPushData(dst, src, -2, depth); // copy the key
+		CopyPushData(dst, src, -1, depth); // copy the value
 		lua_rawset(dst, -3);
 	}
-	depth--;
 
 	return true;
 }
@@ -98,18 +111,229 @@ int LuaUtils::CopyData(lua_State* dst, lua_State* src, int count)
 	}
 	lua_checkstack(dst, count); // FIXME: not enough for table chains
 
-	depth = 0;
-
 	const int startIndex = (srcTop - count + 1);
 	const int endIndex   = srcTop;
 	for (int i = startIndex; i <= endIndex; i++) {
-		CopyPushData(dst, src, i);
+		CopyPushData(dst, src, i, 0);
 	}
 	lua_settop(dst, dstTop + count);
 
 	return count;
 }
 
+/******************************************************************************/
+/******************************************************************************/
+
+static bool BackupData(LuaUtils::DataDump &d, lua_State* src, int index, int depth);
+static bool RestoreData(const LuaUtils::DataDump &d, lua_State* dst, int depth);
+static bool BackupTable(LuaUtils::DataDump &d, lua_State* src, int index, int depth);
+static bool RestoreTable(const LuaUtils::DataDump &d, lua_State* dst, int depth);
+
+
+static bool BackupData(LuaUtils::DataDump &d, lua_State* src, int index, int depth) {
+	++backupSize;
+	const int type = lua_type(src, index);
+	d.type = type;
+	switch (type) {
+		case LUA_TBOOLEAN: {
+			d.bol = lua_toboolean(src, index);
+			break;
+		}
+		case LUA_TNUMBER: {
+			d.num = lua_tonumber(src, index);
+			break;
+		}
+		case LUA_TSTRING: {
+			size_t len = 0;
+			const char* data = lua_tolstring(src, index, &len);
+			if (len > 0) {
+				d.str.resize(len);
+				memcpy(&d.str[0], data, len);
+			}
+			break;
+		}
+		case LUA_TTABLE: {
+			if(!BackupTable(d, src, index, depth))
+				d.type = LUA_TNIL;
+			break;
+		}
+		default: {
+			d.type = LUA_TNIL;
+			break;
+		}
+	}
+	return true;
+}
+
+static bool RestoreData(const LuaUtils::DataDump &d, lua_State* dst, int depth) {
+	const int type = d.type;
+	switch (type) {
+		case LUA_TBOOLEAN: {
+			lua_pushboolean(dst, d.bol);
+			break;
+		}
+		case LUA_TNUMBER: {
+			lua_pushnumber(dst, d.num);
+			break;
+		}
+		case LUA_TSTRING: {
+			lua_pushlstring(dst, d.str.c_str(), d.str.size());
+			break;
+		}
+		case LUA_TTABLE: {
+			RestoreTable(d, dst, depth);
+			break;
+		}
+		default: {
+			lua_pushnil(dst);
+			break;
+		}
+	}
+	return true;
+}
+
+static bool BackupTable(LuaUtils::DataDump &d, lua_State* src, int index, int depth) {
+	if (depth++ > maxDepth)
+		return false;
+
+	const int table = PosLuaIndex(src, index);
+	for (lua_pushnil(src); lua_next(src, table) != 0; lua_pop(src, 1)) {
+		LuaUtils::DataDump dk, dv;
+		BackupData(dk, src, -2, depth);
+		BackupData(dv, src, -1, depth);
+		d.table.push_back(std::pair<LuaUtils::DataDump, LuaUtils::DataDump>(dk ,dv));
+	}
+
+	return true;
+}
+
+static bool RestoreTable(const LuaUtils::DataDump &d, lua_State* dst, int depth) {
+	if (depth++ > maxDepth) {
+		lua_pushnil(dst);
+		return false;
+	}
+
+	lua_newtable(dst);
+	for (std::vector<std::pair<LuaUtils::DataDump, LuaUtils::DataDump> >::const_iterator i = d.table.begin(); i != d.table.end(); ++i) {
+		RestoreData((*i).first, dst, depth);
+		RestoreData((*i).second, dst, depth);
+		lua_rawset(dst, -3);
+	}
+
+	return true;
+}
+
+
+int LuaUtils::Backup(std::vector<LuaUtils::DataDump> &backup, lua_State* src, int count) {
+	const int srcTop = lua_gettop(src);
+	if (srcTop < count)
+		return 0;
+
+	const int startIndex = (srcTop - count + 1);
+	const int endIndex   = srcTop;
+	for (int i = startIndex; i <= endIndex; i++) {
+		backup.push_back(DataDump());
+		BackupData(backup.back(), src, i, 0);
+	}
+
+	return count;
+}
+
+
+int LuaUtils::Restore(const std::vector<LuaUtils::DataDump> &backup, lua_State* dst) {
+	const int dstTop = lua_gettop(dst);
+	int count = backup.size();
+	lua_checkstack(dst, count); // FIXME: not enough for table chains
+
+	for (std::vector<DataDump>::const_iterator i = backup.begin(); i != backup.end(); ++i) {
+		RestoreData(*i, dst, 0);
+	}
+	lua_settop(dst, dstTop + count);
+
+	return count;
+}
+
+
+int LuaUtils::ShallowBackup(std::vector<LuaUtils::ShallowDataDump> &backup, lua_State* src, int count) {
+	const int srcTop = lua_gettop(src);
+	if (srcTop < count)
+		return 0;
+
+	const int startIndex = (srcTop - count + 1);
+	const int endIndex   = srcTop;
+
+	for(int i = startIndex; i <= endIndex; ++i) {
+		const int type = lua_type(src, i);
+		ShallowDataDump sdd;
+		sdd.type = type;
+		switch (type) {
+			case LUA_TBOOLEAN: {
+				sdd.data.bol = lua_toboolean(src, i);
+				break;
+			}
+			case LUA_TNUMBER: {
+				sdd.data.num = lua_tonumber(src, i);
+				break;
+			}
+			case LUA_TSTRING: {
+				size_t len = 0;
+				const char* data = lua_tolstring(src, i, &len);
+				sdd.data.str = new std::string;
+				if (len > 0) {
+					sdd.data.str->resize(len);
+					memcpy(&(*sdd.data.str)[0], data, len);
+				}
+				break;
+			}
+			case LUA_TNIL: {
+				break;
+			}
+			default: {
+				LOG_L(L_WARNING, "ShallowBackup: Invalid type for argument %d", i);
+				break; // nil
+			}
+		}
+		backup.push_back(sdd);
+	}
+
+	return count;
+}
+
+
+int LuaUtils::ShallowRestore(const std::vector<LuaUtils::ShallowDataDump> &backup, lua_State* dst) {
+	int count = backup.size();
+	lua_checkstack(dst, count);
+
+	for (int d = 0; d < count; ++d) {
+		const ShallowDataDump &sdd = backup[d];
+		switch (sdd.type) {
+			case LUA_TBOOLEAN: {
+				lua_pushboolean(dst, sdd.data.bol);
+				break;
+			}
+			case LUA_TNUMBER: {
+				lua_pushnumber(dst, sdd.data.num);
+				break;
+			}
+			case LUA_TSTRING: {
+				lua_pushlstring(dst, sdd.data.str->c_str(), sdd.data.str->size());
+				delete sdd.data.str;
+				break;
+			}
+			case LUA_TNIL: {
+				lua_pushnil(dst);
+				break;
+			}
+			default: {
+				lua_pushnil(dst);
+				LOG_L(L_WARNING, "ShallowRestore: Invalid type for argument %d", d + 1);
+				break; // unhandled type
+			}
+		}
+	}
+
+	return count;
+}
 
 /******************************************************************************/
 /******************************************************************************/
@@ -202,11 +426,11 @@ static bool LowerKeysReal(lua_State* L, int depth)
 				lua_pushnil(L);
 				lua_rawset(L, table);
 				// does the lower case key alread exist in the table?
-				lua_pushstring(L, lowerKey.c_str());
+				lua_pushsstring(L, lowerKey);
 				lua_rawget(L, table);
 				if (lua_isnil(L, -1)) {
 					// lower case does not exist, add it to the changed table
-					lua_pushstring(L, lowerKey.c_str());
+					lua_pushsstring(L, lowerKey);
 					lua_pushvalue(L, -3); // the value
 					lua_rawset(L, changed);
 				}
@@ -330,14 +554,14 @@ void LuaUtils::ParseCommandOptions(lua_State* L, const char* caller,
 }
 
 
-void LuaUtils::ParseCommand(lua_State* L, const char* caller,
-                            int idIndex, Command& cmd)
+Command LuaUtils::ParseCommand(lua_State* L, const char* caller, int idIndex)
 {
 	// cmdID
 	if (!lua_isnumber(L, idIndex)) {
 		luaL_error(L, "%s(): bad command ID", caller);
 	}
-	cmd.id = lua_toint(L, idIndex);
+	const int id = lua_toint(L, idIndex);
+	Command cmd(id);
 
 	// params
 	const int paramTable = (idIndex + 1);
@@ -357,19 +581,21 @@ void LuaUtils::ParseCommand(lua_State* L, const char* caller,
 	// options
 	ParseCommandOptions(L, caller, (idIndex + 2), cmd);
 
-	// NOTE: should do some sanity checking?
+	// XXX should do some sanity checking?
+
+	return cmd;
 }
 
 
-void LuaUtils::ParseCommandTable(lua_State* L, const char* caller,
-                                 int table, Command& cmd)
+Command LuaUtils::ParseCommandTable(lua_State* L, const char* caller, int table)
 {
 	// cmdID
 	lua_rawgeti(L, table, 1);
 	if (!lua_isnumber(L, -1)) {
 		luaL_error(L, "%s(): bad command ID", caller);
 	}
-	cmd.id = lua_toint(L, -1);
+	const int id = lua_toint(L, -1);
+	Command cmd(id);
 	lua_pop(L, 1);
 
 	// params
@@ -394,7 +620,9 @@ void LuaUtils::ParseCommandTable(lua_State* L, const char* caller,
 	ParseCommandOptions(L, caller, lua_gettop(L), cmd);
 	lua_pop(L, 1);
 
-	// NOTE: should do some sanity checking?
+	// XXX should do some sanity checking?
+
+	return cmd;
 }
 
 
@@ -408,8 +636,7 @@ void LuaUtils::ParseCommandArray(lua_State* L, const char* caller,
 		if (!lua_istable(L, -1)) {
 			continue;
 		}
-		Command cmd;
-		ParseCommandTable(L, caller, lua_gettop(L), cmd);
+		Command cmd = ParseCommandTable(L, caller, lua_gettop(L));
 		commands.push_back(cmd);
 	}
 }
@@ -449,9 +676,9 @@ int LuaUtils::Next(const ParamMap& paramMap, lua_State* L)
 	// internal parameters first
 	if (lua_isnil(L, 2)) {
 		const string& nextKey = paramMap.begin()->first;
-		lua_pushstring(L, nextKey.c_str()); // push the key
-		lua_pushvalue(L, 3);                // copy the key
-		lua_gettable(L, 1);                 // get the value
+		lua_pushsstring(L, nextKey); // push the key
+		lua_pushvalue(L, 3);         // copy the key
+		lua_gettable(L, 1);          // get the value
 		return 2;
 	}
 
@@ -461,16 +688,16 @@ int LuaUtils::Next(const ParamMap& paramMap, lua_State* L)
 		ParamMap::const_iterator it = paramMap.find(key);
 		if ((it != paramMap.end()) && (it->second.type != READONLY_TYPE)) {
 			// last key was an internal parameter
-			it++;
+			++it;
 			while ((it != paramMap.end()) && (it->second.type == READONLY_TYPE)) {
-				it++; // skip read-only parameters
+				++it; // skip read-only parameters
 			}
 			if ((it != paramMap.end()) && (it->second.type != READONLY_TYPE)) {
 				// next key is an internal parameter
 				const string& nextKey = it->first;
-				lua_pushstring(L, nextKey.c_str()); // push the key
-				lua_pushvalue(L, 3);                // copy the key
-				lua_gettable(L, 1);                 // get the value (proxied)
+				lua_pushsstring(L, nextKey); // push the key
+				lua_pushvalue(L, 3);         // copy the key
+				lua_gettable(L, 1);          // get the value (proxied)
 				return 2;
 			}
 			// start the user parameters,
@@ -504,7 +731,7 @@ int LuaUtils::Echo(lua_State* L)
 	lua_getglobal(L, "tostring");
 
 	for (int i = 1; i <= args; i++) {
-		const char *s;
+		const char* s;
 		lua_pushvalue(L, -1);     // function to be called
 		lua_pushvalue(L, i);      // value to print
 		lua_call(L, 1, 1);
@@ -518,7 +745,7 @@ int LuaUtils::Echo(lua_State* L)
 		msg += s;
 		lua_pop(L, 1);            // pop result
 	}
-	logOutput.Print(msg);
+	LOG("%s", msg.c_str());
 
 	if ((args != 1) || !lua_istable(L, 1)) {
 		return 0;
@@ -546,7 +773,7 @@ int LuaUtils::Echo(lua_State* L)
 			lua_pop(L, 1);            // pop result
 		}
 	}
-	logOutput.Print(msg);
+	LOG("%s", msg.c_str());
 
 	return 0;
 }
@@ -688,16 +915,46 @@ int LuaUtils::PushDebugTraceback(lua_State *L)
 
 void LuaUtils::PushStringVector(lua_State* L, const vector<string>& vec)
 {
-	lua_newtable(L);
+	lua_createtable(L, vec.size(), 0);
 	for (size_t i = 0; i < vec.size(); i++) {
 		lua_pushnumber(L, (int) (i + 1));
-		lua_pushstring(L, vec[i].c_str());
+		lua_pushsstring(L, vec[i]);
 		lua_rawset(L, -3);
 	}
-	lua_pushstring(L, "n");
-	lua_pushnumber(L, vec.size());
-	lua_rawset(L, -3);
 }
 
 /******************************************************************************/
 /******************************************************************************/
+
+void LuaUtils::PushCommandDesc(lua_State* L, const CommandDescription& cd)
+{
+	const int numParams = cd.params.size();
+	const int numTblKeys = 12;
+
+	lua_checkstack(L, 1 + 1 + 1 + 1);
+	lua_createtable(L, 0, numTblKeys);
+
+	HSTR_PUSH_NUMBER(L, "id",          cd.id);
+	HSTR_PUSH_NUMBER(L, "type",        cd.type);
+	HSTR_PUSH_STRING(L, "name",        cd.name);
+	HSTR_PUSH_STRING(L, "action",      cd.action);
+	HSTR_PUSH_STRING(L, "tooltip",     cd.tooltip);
+	HSTR_PUSH_STRING(L, "texture",     cd.iconname);
+	HSTR_PUSH_STRING(L, "cursor",      cd.mouseicon);
+	HSTR_PUSH_BOOL(L,   "hidden",      cd.hidden);
+	HSTR_PUSH_BOOL(L,   "disabled",    cd.disabled);
+	HSTR_PUSH_BOOL(L,   "showUnique",  cd.showUnique);
+	HSTR_PUSH_BOOL(L,   "onlyTexture", cd.onlyTexture);
+
+	HSTR_PUSH(L, "params");
+
+	lua_createtable(L, 0, numParams);
+
+	for (int p = 0; p < numParams; p++) {
+		lua_pushsstring(L, cd.params[p]);
+		lua_rawseti(L, -2, p + 1);
+	}
+
+	// CmdDesc["params"] = {[1] = "string1", [2] = "string2", ...}
+	lua_settable(L, -3);
+}
