@@ -524,22 +524,22 @@ void CBaseGroundDrawer::UpdateCamRestraints(CCamera* cam)
 	// add restraints for camera sides
 	cam->GetFrustumSides(readmap->currMinHeight - 100.0f,  readmap->currMaxHeight + 30.0f,  SQUARE_SIZE);
 
+	// CAMERA DISTANCE IS ALREADY CHECKED IN CGroundDrawer::GridVisibility()!
+/*
 	// add restraint for maximum view distance (use flat z-dir as side)
 	// this is supposed to prevent (far) terrain from first being drawn
 	// and then immediately z-clipped away
-	const float3& camDir3D  = cam->forward;
-	      float3  camDir2D  = float3(camDir3D.x, 0.0f, camDir3D.z);
-	      float3  camOffset = ZeroVector;
-
-	// FIXME magic constants
-	static const float miny = 0.0f;
-	static const float maxy = 255.0f / 3.5f;
+	const float3& camDir3D = cam->forward;
 
 	// prevent colinearity in top-down view
 	if (fabs(camDir3D.dot(UpVector)) < 0.95f) {
-		camDir2D  = camDir2D.SafeANormalize();
-		camOffset = camDir2D * globalRendering->viewRange * 1.05f;
+		float3 camDir2D  = float3(camDir3D.x, 0.0f, camDir3D.z).SafeANormalize();
+		float3 camOffset = camDir2D * globalRendering->viewRange * 1.05f;
 
+		// FIXME magic constants
+		static const float miny = 0.0f;
+		static const float maxy = 255.0f / 3.5f;
 		cam->GetFrustumSide(camDir2D, camOffset, miny, maxy, SQUARE_SIZE, (camDir3D.y > 0.0f), false);
 	}
+*/
 }
