@@ -3,6 +3,7 @@
 #include "System/mmgr.h"
 
 #include "BasicWater.h"
+#include "ISky.h"
 
 #include "Rendering/Textures/Bitmap.h"
 #include "Map/MapInfo.h"
@@ -43,6 +44,9 @@ void CBasicWater::Draw()
 		return;
 	}
 
+	glPushAttrib(GL_FOG_BIT);
+	ISky::SetupFog();
+
 	if (displist == 0) {
 		displist = glGenLists(1);
 		glNewList(displist, GL_COMPILE);
@@ -87,4 +91,6 @@ void CBasicWater::Draw()
 		glEndList();
 	}
 	glCallList(displist);
+
+	glPopAttrib();
 }
