@@ -1,7 +1,6 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 #include "SkyBox.h"
 #include "Rendering/GlobalRendering.h"
@@ -12,14 +11,24 @@
 #include "Map/ReadMap.h"
 #include "System/Exceptions.h"
 #include "System/float3.h"
-#include "System/GlobalUnsynced.h"
-#include "System/LogOutput.h"
+#include "System/Log/ILog.h"
+
+#define LOG_SECTION_SKY_BOX "SkyBox"
+LOG_REGISTER_SECTION_GLOBAL(LOG_SECTION_SKY_BOX)
+
+// use the specific section for all LOG*() calls in this source file
+#ifdef LOG_SECTION_CURRENT
+	#undef LOG_SECTION_CURRENT
+#endif
+#define LOG_SECTION_CURRENT LOG_SECTION_SKY_BOX
+
 
 CSkyBox::CSkyBox(const std::string& texture)
 {
 	CBitmap btex;
 	if (!btex.Load(texture)) {
-		logOutput.Print("[CSkyBox] could not load skybox texture from file " + texture);
+		LOG_L(L_WARNING, "could not load skybox texture from file %s",
+				texture.c_str());
 		tex = 0;
 	} else {
 		tex = btex.CreateTexture(true);
@@ -96,13 +105,5 @@ void CSkyBox::Draw()
 	glEnable(GL_DEPTH_TEST);
 	glDisable(GL_BLEND);
 
-	glFogfv(GL_FOG_COLOR, mapInfo->atmosphere.fogColor);
-	glFogi(GL_FOG_MODE, GL_LINEAR);
-	glFogf(GL_FOG_START, globalRendering->viewRange*fogStart);
-	glFogf(GL_FOG_END, globalRendering->viewRange);
-	glFogf(GL_FOG_DENSITY, 1.0f);
-
-	if (globalRendering->drawFog) {
-		glEnable(GL_FOG);
-	}
+	ISky::SetupFog();
 }
