@@ -1,7 +1,7 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef MYGL_H
-#define MYGL_H
+#ifndef _MY_GL_H
+#define _MY_GL_H
 
 #define GLEW_STATIC
 #ifndef NOMINMAX
@@ -9,18 +9,31 @@
 #endif
 
 #include <string>
-#ifndef HEADLESS
-	#include <GL/glew.h>
-#else
+#if       defined(HEADLESS)
 	#include "lib/headlessStubs/glewstub.h"
-#endif
+#else
+	#include <GL/glew.h>
+#endif // defined(HEADLESS)
 #include "lib/gml/gml.h"
 
 // includes boost now!
-#include "float3.h"
+#include "System/float3.h"
 
 
-inline void glVertexf3(const float3 &v)
+#if       defined(HEADLESS)
+	// All OpenGL functions should always exists on HEADLESS.
+	// If one does not, we should crash, and it has to be added to glstub.c.
+	// No runtime check should be performed, or it can be optimized away
+	// by the compiler.
+	// This also prevents a compile warning.
+	#define IS_GL_FUNCTION_AVAILABLE(functionName) true
+#else
+	// Check if the functions address is non-NULL.
+	#define IS_GL_FUNCTION_AVAILABLE(functionName) (functionName != NULL)
+#endif // defined(HEADLESS)
+
+
+inline void glVertexf3(const float3& v)
 {
 	glVertex3f(v.x, v.y, v.z);
 }
@@ -30,41 +43,37 @@ inline void glColorf3(const float3& v)
 	glColor3f(v.x, v.y, v.z);
 }
 
-inline void glNormalf3(const float3 &v)
+inline void glNormalf3(const float3& v)
 {
 	glNormal3f(v.x, v.y, v.z);
 }
 
-inline void glTranslatef3(const float3 &v)
+inline void glTranslatef3(const float3& v)
 {
 	glTranslatef(v.x, v.y, v.z);
 }
 
 inline void glSecondaryColorf3(const float3& v)
 {
-	glSecondaryColor3f(v.x,v.y,v.z);
+	glSecondaryColor3f(v.x, v.y, v.z);
 }
 
 inline void glColorf4(const float3& v, const float& alpha)
 {
-	glColor4f(v.x,v.y,v.z,alpha);
+	glColor4f(v.x, v.y, v.z, alpha);
 }
 
-inline void glUniformf3(const GLint& location, const float3 &v)
+inline void glUniformf3(const GLint& location, const float3& v)
 {
-	glUniform3f(location, v.x,v.y,v.z);
+	glUniform3f(location, v.x, v.y, v.z);
 }
 
 
-void glBuildMipmaps(const GLenum target,GLint internalFormat,const GLsizei width,const GLsizei height,const GLenum format,const GLenum type,const void *data);
+void glBuildMipmaps(const GLenum target, GLint internalFormat, const GLsizei width, const GLsizei height, const GLenum format, const GLenum type, const void* data);
 
 void SetTexGen(const float& scaleX, const float& scaleZ, const float& offsetX, const float& offsetZ);
 
-void RandomStartPicture(const std::string& sidePref);
-void LoadStartPicture(const std::string& picture);
 void ClearScreen();
-void PrintLoadMsg(const char* text, bool swapbuffers = true);
-void UnloadStartPicture();
 
 bool ProgramStringIsNative(GLenum target, const char* filename);
 unsigned int LoadVertexProgram(const char* filename);
@@ -81,4 +90,4 @@ void UnloadExtensions();
 class CVertexArray;
 CVertexArray* GetVertexArray();
 
-#endif
+#endif // _MY_GL_H
