@@ -7,15 +7,13 @@
 #include <list>
 #include <vector>
 #include <boost/noncopyable.hpp>
-#include "creg/creg_cond.h"
+#include "System/creg/creg_cond.h"
 #include "FeatureDef.h"
 #include "FeatureSet.h"
 
 
 struct S3DModel;
-class CFileHandler;
-class CLoadSaveInterface;
-class CVertexArray;
+struct UnitDef;
 class LuaTable;
 
 
@@ -29,7 +27,7 @@ public:
 
 	CFeature* CreateWreckage(const float3& pos, const std::string& name,
 		float rot, int facing, int iter, int team, int allyteam, bool emitSmoke,
-		std::string fromUnit, const float3& speed = ZeroVector);
+		const UnitDef* udef, const float3& speed = ZeroVector);
 
 	void Update();
 
@@ -48,8 +46,11 @@ public:
 	const CFeatureSet& GetActiveFeatures() const { return activeFeatures; }
 
 private:
+	FeatureDef* CreateDefaultTreeFeatureDef(const std::string& name) const;
+	FeatureDef* CreateDefaultGeoFeatureDef(const std::string& name) const;
+	FeatureDef* CreateFeatureDef(const LuaTable& luaTable, const std::string& name) const;
+
 	void AddFeatureDef(const std::string& name, FeatureDef* feature);
-	void CreateFeatureDef(const LuaTable& luaTable, const std::string& name);
 
 private:
 	std::map<std::string, const FeatureDef*> featureDefs;
