@@ -1,18 +1,17 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
-#include "mmgr.h"
+#include "System/mmgr.h"
 #include "AirBaseHandler.h"
 
 #include "GlobalSynced.h"
 #include "Sim/Misc/TeamHandler.h"
 #include "Sim/Units/Unit.h"
-#include "Sim/Units/COB/CobInstance.h"
+#include "Sim/Units/Scripts/CobInstance.h"
 #include "Sim/Units/UnitDef.h"
-#include "creg/STL_List.h"
-#include "creg/STL_Set.h"
+#include "System/creg/STL_List.h"
+#include "System/creg/STL_Set.h"
 
-CAirBaseHandler* airBaseHandler = 0;
+CAirBaseHandler* airBaseHandler = NULL;
 
 CR_BIND(CAirBaseHandler, )
 CR_REG_METADATA(CAirBaseHandler,(
@@ -22,7 +21,7 @@ CR_REG_METADATA(CAirBaseHandler,(
 	CR_RESERVED(16)
 	));
 
-CR_BIND_DERIVED(CAirBaseHandler::LandingPad, CObject, (NULL, 0, NULL));
+CR_BIND_DERIVED(CAirBaseHandler::LandingPad, CObject, (0, 0, NULL));
 CR_REG_METADATA_SUB(CAirBaseHandler, LandingPad, (
 	CR_MEMBER(unit),
 	CR_MEMBER(piece),
@@ -39,12 +38,12 @@ CR_REG_METADATA_SUB(CAirBaseHandler, AirBase, (
 	));
 
 
-CAirBaseHandler::CAirBaseHandler(void) : freeBases(teamHandler->ActiveAllyTeams()), bases(teamHandler->ActiveAllyTeams())
+CAirBaseHandler::CAirBaseHandler() : freeBases(teamHandler->ActiveAllyTeams()), bases(teamHandler->ActiveAllyTeams())
 {
 }
 
 
-CAirBaseHandler::~CAirBaseHandler(void)
+CAirBaseHandler::~CAirBaseHandler()
 {
 	// should not be any bases left here...
 	for (int a = 0; a < teamHandler->ActiveAllyTeams(); ++a) {
@@ -57,37 +56,37 @@ CAirBaseHandler::~CAirBaseHandler(void)
 	}
 }
 
-void CAirBaseHandler::RegisterAirBase(CUnit* base)
+void CAirBaseHandler::RegisterAirBase(CUnit* owner)
 {
 	// prevent a unit from being registered as a base more than
 	// once (this can happen eg. when an airbase unit is damaged
 	// and then repaired back to full health, which causes it to
 	// re-register itself via FinishedBuilding())
-	if (airBaseIDs.find(base->id) != airBaseIDs.end()) {
+	if (airBaseIDs.find(owner->id) != airBaseIDs.end()) {
 		return;
 	}
 
-	AirBase* ab = new AirBase(base);
+	AirBase* ab = new AirBase(owner);
 	std::vector<int> args;
 
-	base->script->QueryLandingPads(/*out*/ args);
+	owner->script->QueryLandingPads(/*out*/ args);
 
 	// FIXME: use a set to avoid multiple bases per piece?
-	for (int p = 0; p < (int)args.size(); p++) {
+	for (unsigned int p = 0; p < args.size(); p++) {
 		const int piece = args[p];
-		if (!base->script->PieceExists(piece)) {
+		if (!owner->script->PieceExists(piece)) {
 			continue;
 		}
-		LandingPad* pad = new LandingPad(base, piece, ab);
+		LandingPad* pad = new LandingPad(piece, owner, ab);
 
 		ab->pads.push_back(pad);
 		ab->freePads.push_back(pad);
 	}
 
-	freeBases[base->allyteam].push_back(ab);
-	bases[base->allyteam].push_back(ab);
+	freeBases[owner->allyteam].push_back(ab);
+	bases[owner->allyteam].push_back(ab);
 
-	airBaseIDs.insert(base->id);
+	airBaseIDs.insert(owner->id);
 }
 
 
@@ -118,42 +117,48 @@ void CAirBaseHandler::DeregisterAirBase(CUnit* base)
 	airBaseIDs.erase(base->id);
 }
 
-/** @brief Try to find an airbase and reserve it if one can be found
-Caller must call LeaveLandingPad if it gets one and is finished with it or dies
-it's the callers responsibility to detect if the base dies while its reserved. */
+
 CAirBaseHandler::LandingPad* CAirBaseHandler::FindAirBase(CUnit* unit, float minPower)
 {
-	float closest = 1e30f;
-	PadLstIt foundPad;
-	AirBaseLstIt foundBase = freeBases[unit->allyteam].end();
+	float minDist = 1e30f;
+
+	PadLstIt foundPadIt;
+	AirBaseLstIt foundBaseIt = freeBases[unit->allyteam].end();
 
 	for (AirBaseLstIt bi = freeBases[unit->allyteam].begin(); bi != freeBases[unit->allyteam].end(); ++bi) {
 		CUnit* baseUnit = (*bi)->unit;
 
 		if (unit == baseUnit) {
-			// don't pick ourselves as a landing pad
+			// do not pick ourselves as a landing pad
+			continue;
+		}
+		if (baseUnit->beingBuilt || baseUnit->stunned) {
 			continue;
 		}
 
-		if (baseUnit->pos.SqDistance(unit->pos) >= closest || baseUnit->unitDef->buildSpeed < minPower) {
+		if (baseUnit->pos.SqDistance(unit->pos) >= minDist || baseUnit->unitDef->buildSpeed < minPower) {
 			continue;
 		}
 
-		closest = baseUnit->pos.SqDistance(unit->pos);
-		for (PadLstIt pi = (*bi)->freePads.begin(); pi != (*bi)->freePads.end(); ++pi) {
-			foundPad = pi;
-			foundBase = bi;
+		minDist = baseUnit->pos.SqDistance(unit->pos);
+
+		if ((*bi)->freePads.empty()) {
+			continue;
 		}
+
+		foundPadIt = (*bi)->freePads.begin();
+		foundBaseIt = bi;
 	}
 
+	if (foundBaseIt != freeBases[unit->allyteam].end()) {
+		AirBase* foundBase = *foundBaseIt;
+		LandingPad* foundPad = *foundPadIt;
 
-	if (foundBase != freeBases[unit->allyteam].end()) {
-		LandingPad* found = *foundPad;
-		(*foundBase)->freePads.erase(foundPad);
-		return found;
+		foundBase->freePads.erase(foundPadIt);
+		return foundPad;
 	}
 
-	return 0;
+	return NULL;
 }
 
 
@@ -163,30 +168,32 @@ void CAirBaseHandler::LeaveLandingPad(LandingPad* pad)
 }
 
 
-/** @brief Try to find the closest airbase even if it's reserved */
 float3 CAirBaseHandler::FindClosestAirBasePos(CUnit* unit, float minPower)
 {
-	float closest = 1e30f;
-	AirBaseLstIt foundBase = freeBases[unit->allyteam].end();
+	float minDist = 1e30f;
+	AirBaseLstIt foundBaseIt = freeBases[unit->allyteam].end();
 
 	for (AirBaseLstIt bi = freeBases[unit->allyteam].begin(); bi != freeBases[unit->allyteam].end(); ++bi) {
 		CUnit* baseUnit = (*bi)->unit;
 
 		if (unit == baseUnit) {
-			// don't pick ourselves as a landing pad
+			// do not pick ourselves as a landing pad
+			continue;
+		}
+		if (baseUnit->beingBuilt || baseUnit->stunned) {
 			continue;
 		}
 
-		if (baseUnit->pos.SqDistance(unit->pos) >= closest || baseUnit->unitDef->buildSpeed < minPower) {
+		if (baseUnit->pos.SqDistance(unit->pos) >= minDist || baseUnit->unitDef->buildSpeed < minPower) {
 			continue;
 		}
 
-		closest = baseUnit->pos.SqDistance(unit->pos);
-		foundBase = bi;
+		minDist = baseUnit->pos.SqDistance(unit->pos);
+		foundBaseIt = bi;
 	}
 
-	if (foundBase != freeBases[unit->allyteam].end()) {
-		return (*foundBase)->unit->pos;
+	if (foundBaseIt != freeBases[unit->allyteam].end()) {
+		return (*foundBaseIt)->unit->pos;
 	}
 
 	return ZeroVector;
