@@ -282,10 +282,9 @@ bool CCollisionHandler::Intersect(const CUnit* u, const float3& p0, const float3
 bool CCollisionHandler::Intersect(const CFeature* f, const float3& p0, const float3& p1, CollisionQuery* q)
 {
 	const CollisionVolume* v = f->collisionVolume;
-	const float3 relMidPos(f->midPos - f->pos);
 
 	CMatrix44f m(f->transMatrix);
-	m.Translate(relMidPos);
+	m.Translate(f->relMidPos);
 	m.Translate(v->GetOffsets());
 
 	return CCollisionHandler::Intersect(v, m, p0, p1, q);
@@ -645,8 +644,11 @@ bool CCollisionHandler::IntersectBox(const CollisionVolume* v, const float3& pi0
 	if ((ba && bb && bc) /* && (bd && be && bf) */) {
 		// terminate early in the special case
 		// that shot originated within volume
-		q->b0 = true; q->p0 = ZVEC;
-		q->b1 = true; q->p1 = ZVEC;
+		if (q != NULL) {
+			q->b0 = true; q->p0 = ZVEC;
+			q->b1 = true; q->p1 = ZVEC;
+		}
+
 		return true;
 	}
 
@@ -732,7 +734,7 @@ bool CCollisionHandler::IntersectBox(const CollisionVolume* v, const float3& pi0
 	const bool b0 = (dSq0 <= segLenSq);
 	const bool b1 = (dSq1 <= segLenSq);
 
-	if (q) {
+	if (q != NULL) {
 		q->b0 = b0; q->b1 = b1;
 		q->t0 = tn; q->t1 = tf;
 		q->p0 = p0; q->p1 = p1;
