@@ -6,34 +6,40 @@
 #include "System/Object.h"
 
 #include <list>
+#include <map>
 #include <boost/noncopyable.hpp>
-#include "System/float3.h"
+#include "System/Object.h"
 
 class CWeapon;
 class CWeaponProjectile;
 class CPlasmaRepulser;
 class CProjectile;
+class float3;
 
-class CInterceptHandler : public boost::noncopyable
+class CInterceptHandler : public CObject, boost::noncopyable
 {
 	CR_DECLARE(CInterceptHandler)
 
 public:
-	CInterceptHandler();
-	~CInterceptHandler();
+	void Update(bool forced);
+
+	void AddInterceptorWeapon(CWeapon* weapon) { interceptors.push_back(weapon); }
+	void RemoveInterceptorWeapon(CWeapon* weapon) { interceptors.remove(weapon); }
 
-	void AddInterceptorWeapon(CWeapon* weapon);
-	void RemoveInterceptorWeapon(CWeapon* weapon);
 	void AddInterceptTarget(CWeaponProjectile* target, const float3& destination);
-
 	void AddShieldInterceptableProjectile(CWeaponProjectile* p);
+
 	float AddShieldInterceptableBeam(CWeapon* emitter, const float3& start, const float3& dir, float length, float3& newDir, CPlasmaRepulser*& repulsedBy);
-	void AddPlasmaRepulser(CPlasmaRepulser* r);
-	void RemovePlasmaRepulser(CPlasmaRepulser* r);
+
+	void AddPlasmaRepulser(CPlasmaRepulser* r) { repulsors.push_back(r); }
+	void RemovePlasmaRepulser(CPlasmaRepulser* r) { repulsors.remove(r); }
+
+	void DependentDied(CObject* o);
 
 private:
 	std::list<CWeapon*> interceptors;
-	std::list<CPlasmaRepulser*> plasmaRepulsors;
+	std::list<CPlasmaRepulser*> repulsors;
+	std::map<int, CWeaponProjectile*> interceptables;
 };
 
 extern CInterceptHandler interceptHandler;
