@@ -1,22 +1,21 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 #include <list>
 #include <cstdlib>
 #include <cstring>
 
 #include "LosHandler.h"
-
 #include "ModInfo.h"
+
 #include "Sim/Units/Unit.h"
 #include "Sim/Misc/TeamHandler.h"
 #include "Map/ReadMap.h"
-#include "System/LogOutput.h"
+#include "System/Log/ILog.h"
 #include "System/TimeProfiler.h"
-#include "creg/STL_Deque.h"
-#include "creg/STL_List.h"
+#include "System/creg/STL_Deque.h"
+#include "System/creg/STL_List.h"
 
 using std::min;
 using std::max;
@@ -62,11 +61,6 @@ CR_REG_METADATA(CLosHandler,(
 CR_REG_METADATA_SUB(CLosHandler,DelayedInstance,(
 		CR_MEMBER(instance),
 		CR_MEMBER(timeoutTime)));
-/*
-CR_REG_METADATA_SUB(CLosHandler,CPoint,(
-		CR_MEMBER(x),
-		CR_MEMBER(y)));
-*/
 
 
 //////////////////////////////////////////////////////////////////////
@@ -78,9 +72,9 @@ CLosHandler* loshandler;
 
 
 CLosHandler::CLosHandler() :
-	losMap(teamHandler->ActiveAllyTeams()),
-	airLosMap(teamHandler->ActiveAllyTeams()),
-	//airAlgo(int2(airSizeX, airSizeY), -1e6f, 15, readmap->mipHeightmap[airMipLevel]),
+	losMaps(teamHandler->ActiveAllyTeams()),
+	airLosMaps(teamHandler->ActiveAllyTeams()),
+	// airAlgo(int2(airSizeX, airSizeY), -1e6f, 15, readmap->GetMIPHeightMapSynced(airMipLevel)),
 	losMipLevel(modInfo.losMipLevel),
 	airMipLevel(modInfo.airMipLevel),
 	losDiv(SQUARE_SIZE * (1 << losMipLevel)),
@@ -92,11 +86,11 @@ CLosHandler::CLosHandler() :
 	losSizeX(std::max(1, gs->mapx >> losMipLevel)),
 	losSizeY(std::max(1, gs->mapy >> losMipLevel)),
 	requireSonarUnderWater(modInfo.requireSonarUnderWater),
-	losAlgo(int2(losSizeX, losSizeY), -1e6f, 15, readmap->mipHeightmap[losMipLevel])
+	losAlgo(int2(losSizeX, losSizeY), -1e6f, 15, readmap->GetMIPHeightMapSynced(losMipLevel))
 {
 	for (int a = 0; a < teamHandler->ActiveAllyTeams(); ++a) {
-		losMap[a].SetSize(losSizeX, losSizeY);
-		airLosMap[a].SetSize(airSizeX, airSizeY);
+		losMaps[a].SetSize(losSizeX, losSizeY);
+		airLosMaps[a].SetSize(airSizeX, airSizeY);
 	}
 }
 
@@ -114,23 +108,30 @@ CLosHandler::~CLosHandler()
 }
 
 
-void CLosHandler::MoveUnit(CUnit *unit, bool redoCurrent)
+void CLosHandler::MoveUnit(CUnit* unit, bool redoCurrent)
 {
-	SCOPED_TIMER("Los");
-	const float3& losPos = unit->pos;
-
-	const int allyteam = unit->allyteam;
-	unit->lastLosUpdate = gs->frameNum;
+	SCOPED_TIMER("LOSHandler::MoveUnit");
 
+	// NOTE: under normal circumstances, this only gets called if a unit
+	// has moved to a new map square since its last SlowUpdate cycle, so
+	// any units that changed position between enabling and disabling of
+	// globalLOS and *stopped* will continue to provide LOS at their old
+	// square *after* it is disabled (until they are moved again)
+	if (gs->globalLOS) { return; }
 	if (unit->losRadius <= 0 && unit->airLosRadius <= 0) {
 		return;
 	}
 
-	const int baseX = max(0, min(losSizeX - 1, (int)(losPos.x * invLosDiv)));
-	const int baseY = max(0, min(losSizeY - 1, (int)(losPos.z * invLosDiv)));
+	unit->lastLosUpdate = gs->frameNum;
+
+	const float3& losPos = unit->pos;
+	const int allyteam = unit->allyteam;
+
+	const int baseX = max(0, min(losSizeX - 1, int(losPos.x * invLosDiv)));
+	const int baseY = max(0, min(losSizeY - 1, int(losPos.z * invLosDiv)));
 	const int baseSquare = baseY * losSizeX + baseX;
-	const int baseAirX = max(0, min(airSizeX - 1, (int)(losPos.x * invAirDiv)));
-	const int baseAirY = max(0, min(airSizeY - 1, (int)(losPos.z * invAirDiv)));
+	const int baseAirX = max(0, min(airSizeX - 1, int(losPos.x * invAirDiv)));
+	const int baseAirY = max(0, min(airSizeY - 1, int(losPos.z * invAirDiv)));
 
 	LosInstance* instance = NULL;
 	if (redoCurrent) {
@@ -149,8 +150,10 @@ void CLosHandler::MoveUnit(CUnit *unit, bool redoCurrent)
 		if (unit->los && (unit->los->baseSquare == baseSquare)) {
 			return;
 		}
+
 		FreeInstance(unit->los);
-		int hash = GetHashNum(unit);
+		const int hash = GetHashNum(unit);
+
 		std::list<LosInstance*>::iterator lii;
 		for (lii = instanceHash[hash].begin(); lii != instanceHash[hash].end(); ++lii) {
 			if ((*lii)->baseSquare == baseSquare         &&
@@ -163,9 +166,19 @@ void CLosHandler::MoveUnit(CUnit *unit, bool redoCurrent)
 				return;
 			}
 		}
-		instance=new(mempool.Alloc(sizeof(LosInstance))) LosInstance(unit->losRadius, unit->airLosRadius, allyteam, int2(baseX,baseY), baseSquare, int2(baseAirX, baseAirY), hash, unit->losHeight);
+
+		instance = new(mempool.Alloc(sizeof(LosInstance))) LosInstance(
+			unit->losRadius,
+			unit->airLosRadius,
+			allyteam,
+			int2(baseX,baseY),
+			baseSquare,
+			int2(baseAirX, baseAirY),
+			hash, unit->losHeight
+		);
+
 		instanceHash[hash].push_back(instance);
-		unit->los=instance;
+		unit->los = instance;
 	}
 
 	LosAdd(instance);
@@ -175,30 +188,34 @@ void CLosHandler::MoveUnit(CUnit *unit, bool redoCurrent)
 void CLosHandler::LosAdd(LosInstance* instance)
 {
 	assert(instance);
-	assert(instance->allyteam < teamHandler->ActiveAllyTeams());
-	assert(instance->allyteam >= 0);
+	assert(teamHandler->IsValidAllyTeam(instance->allyteam));
 
 	losAlgo.LosAdd(instance->basePos, instance->losSize, instance->baseHeight, instance->losSquares);
 
-	if (instance->losSize > 0) { losMap[instance->allyteam].AddMapSquares(instance->losSquares, 1); }
-	if (instance->airLosSize > 0) { airLosMap[instance->allyteam].AddMapArea(instance->baseAirPos, instance->airLosSize, 1); }
+	if (instance->losSize > 0) { losMaps[instance->allyteam].AddMapSquares(instance->losSquares, instance->allyteam, 1); }
+	if (instance->airLosSize > 0) { airLosMaps[instance->allyteam].AddMapArea(instance->baseAirPos, instance->allyteam, instance->airLosSize, 1); }
 }
 
 
 void CLosHandler::FreeInstance(LosInstance* instance)
 {
-	if(instance==0)
+	if (instance == 0)
 		return;
+
 	instance->refCount--;
-	if(instance->refCount==0){
+
+	if (instance->refCount == 0) {
 		CleanupInstance(instance);
-		if(!instance->toBeDeleted){
-			instance->toBeDeleted=true;
+
+		if (!instance->toBeDeleted) {
+			instance->toBeDeleted = true;
 			toBeDeleted.push_back(instance);
 		}
 
 		if (instance->hashNum >= LOSHANDLER_MAGIC_PRIME || instance->hashNum < 0) {
-			logOutput.Print("[LosHandler::FreeInstance][1] bad LOS-instance hash (%d)", instance->hashNum);
+			LOG_L(L_WARNING,
+					"[LosHandler::FreeInstance][1] bad LOS-instance hash (%d)",
+					instance->hashNum);
 		}
 
 		if (toBeDeleted.size() > 500) {
@@ -206,17 +223,22 @@ void CLosHandler::FreeInstance(LosInstance* instance)
 			toBeDeleted.pop_front();
 
 			if (i->hashNum >= LOSHANDLER_MAGIC_PRIME || i->hashNum < 0) {
-				logOutput.Print("[LosHandler::FreeInstance][2] bad LOS-instance hash (%d)", i->hashNum);
+				LOG_L(L_WARNING,
+						"[LosHandler::FreeInstance][2] bad LOS-instance hash (%d)",
+						i->hashNum);
 				return;
 			}
-			i->toBeDeleted=false;
-			if(i->refCount==0){
+
+			i->toBeDeleted = false;
+
+			if (i->refCount == 0) {
 				std::list<LosInstance*>::iterator lii;
-				for(lii=instanceHash[i->hashNum].begin();lii!=instanceHash[i->hashNum].end();++lii){
-					if((*lii)==i){
+
+				for (lii = instanceHash[i->hashNum].begin(); lii != instanceHash[i->hashNum].end(); ++lii) {
+					if ((*lii) == i) {
 						instanceHash[i->hashNum].erase(lii);
 						i->_DestructInstance(i);
-						mempool.Free(i,sizeof(LosInstance));
+						mempool.Free(i, sizeof(LosInstance));
 						break;
 					}
 				}
@@ -228,8 +250,9 @@ void CLosHandler::FreeInstance(LosInstance* instance)
 
 int CLosHandler::GetHashNum(CUnit* unit)
 {
-	unsigned int t=unit->mapSquare*unit->losRadius+unit->allyteam;
-	t^=*(unsigned int*)&unit->losHeight;
+	const unsigned int t =
+		(unit->mapSquare * unit->losRadius + unit->allyteam) ^
+		(*(unsigned int*) &unit->losHeight);
 	//! hash-value range is [0, LOSHANDLER_MAGIC_PRIME - 1]
 	return (t % LOSHANDLER_MAGIC_PRIME);
 }
@@ -246,14 +269,14 @@ void CLosHandler::AllocInstance(LosInstance* instance)
 
 void CLosHandler::CleanupInstance(LosInstance* instance)
 {
-	if (instance->losSize > 0) { losMap[instance->allyteam].AddMapSquares(instance->losSquares, -1); }
-	if (instance->airLosSize > 0) { airLosMap[instance->allyteam].AddMapArea(instance->baseAirPos, instance->airLosSize, -1); }
+	if (instance->losSize > 0) { losMaps[instance->allyteam].AddMapSquares(instance->losSquares, instance->allyteam, -1); }
+	if (instance->airLosSize > 0) { airLosMaps[instance->allyteam].AddMapArea(instance->baseAirPos, instance->allyteam, instance->airLosSize, -1); }
 }
 
 
 void CLosHandler::Update(void)
 {
-	while(!delayQue.empty() && delayQue.front().timeoutTime<gs->frameNum){
+	while (!delayQue.empty() && delayQue.front().timeoutTime < gs->frameNum) {
 		FreeInstance(delayQue.front().instance);
 		delayQue.pop_front();
 	}
@@ -263,8 +286,8 @@ void CLosHandler::Update(void)
 void CLosHandler::DelayedFreeInstance(LosInstance* instance)
 {
 	DelayedInstance di;
-	di.instance=instance;
-	di.timeoutTime=gs->frameNum+45;
+	di.instance = instance;
+	di.timeoutTime = (gs->frameNum + (GAME_SPEED + (GAME_SPEED >> 1)));
 
 	delayQue.push_back(di);
 }
