@@ -10,8 +10,8 @@
 #include "Game/GameSetup.h"
 #include "Game/GlobalUnsynced.h"
 #include "Game/Messages.h"
-#include "Game/UI/LuaUI.h"
 #include "Lua/LuaRules.h"
+#include "Lua/LuaUI.h"
 #include "Sim/Units/Unit.h"
 #include "Sim/Units/UnitHandler.h"
 #include "Sim/Units/UnitDef.h"
