@@ -21,28 +21,23 @@ class CTeam : public TeamBase, private boost::noncopyable //! cannot allow shall
 	CR_DECLARE(CTeam);
 public:
 	CTeam();
-	~CTeam();
-public:
 
-	/**
-	 * This has to be called for every team before SlowUpdates start,
-	 * otherwise values get overwritten.
-	 */
-	void ResetFrameVariables();
+	void ResetResourceState();
 	void SlowUpdate();
 
-	void AddMetal(float amount, bool handicap = true);
-	void AddEnergy(float amount, bool handicap = true);
+	void AddMetal(float amount, bool useIncomeMultiplier = true);
+	void AddEnergy(float amount, bool useIncomeMultiplier = true);
 	bool UseEnergy(float amount);
 	bool UseMetal(float amount);
-	bool UseEnergyUpkeep(float amount);
-	bool UseMetalUpkeep(float amount);
+	bool AtUnitLimit() const { return (units.size() >= maxUnits); }
 
 	void GiveEverythingTo(const unsigned toTeam);
 
-	void Died();
+	void Died(bool normalDeath = true);
+	void AddPlayer(int playerNum);
+	void KillAIs();
 
-	void StartposMessage(const float3& pos);
+	void StartposMessage(const float3& pos) { startPos = pos; }
 
 	CTeam& operator=(const TeamBase& base);
 
@@ -63,10 +58,12 @@ public:
 	void AddUnit(CUnit* unit, AddType type);
 	void RemoveUnit(CUnit* unit, RemoveType type);
 
+
 	int teamNum;
+	unsigned int maxUnits;
+
 	bool isDead;
 	bool gaia;
-	int lineageRoot;
 
 	/// color info is unsynced
 	unsigned char origColor[4];
@@ -79,12 +76,10 @@ public:
 	float metalPull,    prevMetalPull;
 	float metalIncome,  prevMetalIncome;
 	float metalExpense, prevMetalExpense;
-	float metalUpkeep,  prevMetalUpkeep;
 
 	float energyPull,    prevEnergyPull;
 	float energyIncome,  prevEnergyIncome;
 	float energyExpense, prevEnergyExpense;
-	float energyUpkeep,  prevEnergyUpkeep;
 
 	SyncedFloat metalStorage, energyStorage;
 
@@ -101,12 +96,6 @@ public:
 	std::list<TeamStatistics> statHistory;
 	typedef TeamStatistics Statistics; //! for easier access via CTeam::Statistics
 
-	/// number of units with commander tag in team, if it reaches zero with cmd ends the team dies
-	int numCommanders;
-
-	void CommanderDied(CUnit* commander);
-	void LeftLineage(CUnit* unit);
-
 	/// mod controlled parameters
 	LuaRulesParams::Params  modParams;
 	LuaRulesParams::HashMap modParamsMap; /// name map for mod parameters
