@@ -37,6 +37,23 @@ CONFIG(int, MaxPathCostsMemoryFootPrint).defaultValue(512 * 1024 * 1024);
 
 static const std::string PATH_CACHE_DIR = "cache/paths/";
 
+static size_t GetNumThreads() {
+	size_t numThreads = std::max(0, configHandler->GetInt("HardwareThreadCount"));
+
+	if (numThreads == 0) {
+		// auto-detect
+		#if (BOOST_VERSION >= 103500)
+		numThreads = boost::thread::hardware_concurrency();
+		#elif defined(USE_GML)
+		numThreads = gmlCPUCount();
+		#else
+		numThreads = 1;
+		#endif
+	}
+
+	return numThreads;
+}
+
 #if !defined(USE_MMGR)
 void* CPathEstimator::operator new(size_t size) { return PathAllocator::Alloc(size); }
 void CPathEstimator::operator delete(void* p, size_t size) { PathAllocator::Free(p, size); }
@@ -115,18 +132,7 @@ CPathEstimator::~CPathEstimator()
 
 void CPathEstimator::InitEstimator(const std::string& cacheFileName, const std::string& map)
 {
-	unsigned int numThreads = std::max(0, configHandler->GetInt("HardwareThreadCount"));
-
-	if (numThreads == 0) {
-		// auto-detect
-		#if (BOOST_VERSION >= 103500)
-		numThreads = boost::thread::hardware_concurrency();
-		#elif defined(USE_GML)
-		numThreads = gmlCPUCount();
-		#else
-		numThreads = 1;
-		#endif
-	}
+	const unsigned int numThreads = GetNumThreads();
 
 	if (threads.size() != numThreads) {
 		threads.resize(numThreads);
@@ -245,7 +251,7 @@ void CPathEstimator::EstimatePathCosts(int idx, int thread) {
 		nextCostMessage = idx + blockStates.GetSize() / 16;
 		char calcMsg[128];
 		sprintf(calcMsg, "PathCosts: precached %d of %d", idx, blockStates.GetSize());
-		net->Send(CBaseNetProtocol::Get().SendCPUUsage(0x1 | BLOCK_SIZE | (idx<<8)));
+		net->Send(CBaseNetProtocol::Get().SendCPUUsage(0x1 | BLOCK_SIZE | (idx << 8)));
 		loadscreen->SetLoadMessage(calcMsg, (idx != 0));
 	}
 
