@@ -1,7 +1,7 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef PIECEPROJECTILE_H
-#define PIECEPROJECTILE_H
+#ifndef PIECE_PROJECTILE_H
+#define PIECE_PROJECTILE_H
 
 #include "Projectile.h"
 #include "Sim/Misc/DamageArray.h"
@@ -28,44 +28,49 @@ class CPieceProjectile: public CProjectile
 
 	void creg_Serialize(creg::ISerializer& s);
 
-	int flags;
-	int dispList;
-	const S3DModelPiece* omp;
-	float3 spinVec;
-	float spinSpeed;
-	float spinAngle;
-	float alphaThreshold;
-
-	float3 oldSmoke, oldSmokeDir;
-	bool drawTrail;
-	CSmokeTrailProjectile* curCallback;
-	int* numCallback;
-	int age;
-
-	CCustomExplosionGenerator ceg;
-
-	struct OldInfo {
-		float3 pos;
-		float size;
-	};
-	OldInfo* oldInfos[8];
-	int colorTeam;
-
 public:
 	CPieceProjectile(const float3& pos, const float3& speed, LocalModelPiece* piece, int flags, CUnit* owner, float radius);
-	virtual ~CPieceProjectile(void);
+	virtual ~CPieceProjectile();
+	virtual void Detach();
+
 	void Update();
 	void Draw();
 	virtual void DrawOnMinimap(CVertexArray& lines, CVertexArray& points);
 	void Collision();
 	void Collision(CUnit* unit);
 
-	void DrawCallback(void);
+	void DrawCallback();
 
 private:
-	bool HasVertices();
+	bool HasVertices() const;
 	float3 RandomVertexPos();
+
+public:
+	unsigned int flags;
+	unsigned int dispList;
+	unsigned int cegID;
+
+	const S3DModelPiece* omp;
+
+	float3 spinVec;
+	float spinSpeed;
+	float spinAngle;
+
+	float alphaThreshold;
+
+	float3 oldSmokePos;
+	float3 oldSmokeDir;
+	bool drawTrail;
+
+	struct OldInfo {
+		float3 pos;
+		float size;
+	};
+	OldInfo* oldInfos[8];
+	CSmokeTrailProjectile* curCallback;
+
+	int age;
+	int colorTeam;
 };
 
-
-#endif /* PIECEPROJECTILE_H */
+#endif /* PIECE_PROJECTILE_H */
