@@ -9,12 +9,21 @@ class CGeoSquareProjectile : public CProjectile
 {
 	CR_DECLARE(CGeoSquareProjectile);
 public:
-	CGeoSquareProjectile(const float3& p1, const float3& p2, const float3& v1, const float3& v2, float w1, float w2);
+	CGeoSquareProjectile(const float3& p1, const float3& p2, const float3& v1,
+			const float3& v2, float w1, float w2);
 	virtual ~CGeoSquareProjectile();
 
 	void Draw();
 	void Update();
 
+	void SetColor(float r, float g, float b, float a) {
+		this->r = r;
+		this->g = g;
+		this->b = b;
+		this->a = a;
+	}
+
+private:
 	float3 p1, p2, v1, v2; ///< FIXME what is this?
 	float w1, w2; ///< FIXME what is this?
 	float r, g, b, a; ///< RGBA color
