@@ -1,11 +1,10 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 #include "Game/Camera.h"
 #include "GfxProjectile.h"
-#include "Rendering/ProjectileDrawer.hpp"
+#include "Rendering/ProjectileDrawer.h"
 #include "Rendering/GL/VertexArray.h"
 #include "Rendering/Textures/TextureAtlas.h"
 #include "Rendering/Colors.h"
@@ -36,7 +35,7 @@ CGfxProjectile::CGfxProjectile(): CProjectile()
 }
 
 CGfxProjectile::CGfxProjectile(const float3& pos, const float3& speed, int lifeTime, const float3& color):
-	CProjectile(pos, speed, 0, false, false, false),
+	CProjectile(pos, speed, NULL, false, false, false),
 	creationTime(gs->frameNum),
 	lifeTime(lifeTime)
 {
