@@ -11,13 +11,15 @@ class CGfxProjectile : public CProjectile
 
 public:
 	CGfxProjectile();
-	CGfxProjectile(const float3& pos,const float3& speed,int lifeTime,const float3& color);
+	CGfxProjectile(const float3& pos, const float3& speed, int lifeTime,
+			const float3& color);
 	virtual ~CGfxProjectile();
 
 	void Update();
 	void Draw();
 	virtual void DrawOnMinimap(CVertexArray& lines, CVertexArray& points);
 
+private:
 	int creationTime;
 	int lifeTime;
 	unsigned char color[4];
