@@ -1,16 +1,15 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 #include "ShieldPartProjectile.h"
-#include "Rendering/ProjectileDrawer.hpp"
+#include "Rendering/ProjectileDrawer.h"
 #include "Rendering/GL/myGL.h"
 #include "Rendering/GL/VertexArray.h"
 #include "Rendering/Textures/TextureAtlas.h"
 #include "Sim/Projectiles/ProjectileHandler.h"
 
-CR_BIND_DERIVED(CShieldPartProjectile, CProjectile, (ZeroVector, 0, 0, 0, ZeroVector, 0, NULL, NULL));
+CR_BIND_DERIVED(CShieldPartProjectile, CProjectile, (ZeroVector, 0, 0, 0.0f, ZeroVector, 0.0f, NULL, NULL));
 
 CR_REG_METADATA(CShieldPartProjectile,(
 	CR_MEMBER(centerPos),
