@@ -1,10 +1,9 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef __EXPLOSIVE_PROJECTILE_H__
-#define __EXPLOSIVE_PROJECTILE_H__
+#ifndef _EXPLOSIVE_PROJECTILE_H
+#define _EXPLOSIVE_PROJECTILE_H
 
 #include "WeaponProjectile.h"
-#include "Sim/Misc/DamageArray.h"
 
 class CExplosiveProjectile : public CWeaponProjectile
 {
@@ -16,14 +15,17 @@ public:
 		float gravity = 0.0f);
 
 	void Update();
-	void Draw(void);
+	void Draw();
 	void Collision(CUnit* unit);
 	void Collision();
-	int ShieldRepulse(CPlasmaRepulser* shield,float3 shieldPos, float shieldForce, float shieldMaxSpeed);
 
+	int ShieldRepulse(CPlasmaRepulser* shield, float3 shieldPos,
+			float shieldForce, float shieldMaxSpeed);
+
+private:
 	float areaOfEffect;
 	float invttl;
 	float curTime;
 };
 
-#endif // __EXPLOSIVE_PROJECTILE_H__
+#endif // _EXPLOSIVE_PROJECTILE_H
