@@ -1,39 +1,43 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef MISSILEPROJECTILE_H
-#define MISSILEPROJECTILE_H
+#ifndef MISSILE_PROJECTILE_H
+#define MISSILE_PROJECTILE_H
 
 #include "WeaponProjectile.h"
-#include "Sim/Misc/DamageArray.h"
 
 class CUnit;
 
-class CMissileProjectile :
-	public CWeaponProjectile
+class CMissileProjectile : public CWeaponProjectile
 {
 	CR_DECLARE(CMissileProjectile);
 protected:
 	void UpdateGroundBounce();
 public:
-	CMissileProjectile(const float3& pos, const float3& speed, CUnit* owner, float areaOfEffect,
-		float maxSpeed, int ttl, CUnit* target, const WeaponDef *weaponDef, float3 targetPos);
-	~CMissileProjectile(void);
+	CMissileProjectile(const float3& pos, const float3& speed, CUnit* owner,
+			float areaOfEffect, float maxSpeed, int ttl, CUnit* target,
+			const WeaponDef* weaponDef, float3 targetPos);
+	~CMissileProjectile();
 	void DependentDied(CObject* o);
 	void Collision(CUnit* unit);
 	void Collision();
 
-	void Update(void);
-	void Draw(void);
+	void Update();
+	void Draw();
 
-	int ShieldRepulse(CPlasmaRepulser* shield, float3 shieldPos, float shieldForce, float shieldMaxSpeed);
+	int ShieldRepulse(CPlasmaRepulser* shield, float3 shieldPos,
+			float shieldForce, float shieldMaxSpeed);
 
+private:
 	float maxSpeed;
 	float curSpeed;
 	float areaOfEffect;
 	int age;
-	float3 oldSmoke,oldDir;
+	float3 oldSmoke;
+	float3 oldDir;
 	CUnit* target;
+public:
 	CProjectile* decoyTarget;
+private:
 	bool drawTrail;
 	int numParts;
 	float3 targPos;
@@ -55,7 +59,10 @@ public:
 	float extraHeight;
 	float extraHeightDecay;
 	int extraHeightTime;
+
+	/// the smokes life-time in frames
+	static const float SMOKE_TIME;
 };
 
 
-#endif /* MISSILEPROJECTILE_H */
+#endif /* MISSILE_PROJECTILE_H */
