@@ -28,8 +28,6 @@ public:
 
 	CFactoryCAI(CUnit* owner);
 	CFactoryCAI();
-	~CFactoryCAI();
-	void PostLoad();
 
 	int GetDefaultCmd(const CUnit* pointed, const CFeature* feature);
 	void SlowUpdate();
@@ -39,21 +37,15 @@ public:
 	void InsertBuildCommand(CCommandQueue::iterator& it, const Command& c);
 	bool RemoveBuildCommand(CCommandQueue::iterator& it);
 
-	void ExecuteStop(Command &c);
-
-	void UpdateIconName(int id, BuildOption& bo);
+	void DecreaseQueueCount(const Command& c, BuildOption& buildOption);
+	void ExecuteStop(Command& c);
 
 	CCommandQueue newUnitCommands;
 
 	std::map<int, BuildOption> buildOptions;
 
-	bool building;
-
-	int lastRestrictedWarning;
-
 private:
-
-	void CancelRestrictedUnit(const Command& c, BuildOption& buildOption);
+	void UpdateIconName(int id, const BuildOption& bo);
 };
 
 #endif // _FACTORY_AI_H_
