@@ -58,7 +58,7 @@ UnitDef::UnitDef()
 , cobID(-1)
 , collisionVolume(NULL)
 , decoyDef(NULL)
-, techLevel(0)
+, techLevel(-1)
 , metalUpkeep(0.0f)
 , energyUpkeep(0.0f)
 , metalMake(0.0f)
@@ -86,6 +86,7 @@ UnitDef::UnitDef()
 , turnInPlace(false)
 , turnInPlaceSpeedLimit(0.0f)
 , upright(false)
+, blocking(true)
 , collide(false)
 , losHeight(0.0f)
 , radarHeight(0.0f)
@@ -108,14 +109,20 @@ UnitDef::UnitDef()
 , resurrectSpeed(0.0f)
 , captureSpeed(0.0f)
 , terraformSpeed(0.0f)
+
 , mass(0.0f)
+, crushResistance(0.0f)
+
+, canSubmerge(false)
+, canfly(false)
+, floatOnWater(false)
 , pushResistant(false)
 , strafeToAttack(false)
 , minCollisionSpeed(0.0f)
 , slideTolerance(0.0f)
 , maxHeightDif(0.0f)
-, minWaterDepth(0.0f)
 , waterline(0.0f)
+, minWaterDepth(0.0f)
 , maxWaterDepth(0.0f)
 , armoredMultiple(0.0f)
 , armorType(0)
@@ -131,13 +138,7 @@ UnitDef::UnitDef()
 , maxWeaponRange(0.0f)
 , maxCoverage(0.0f)
 , buildPic(NULL)
-, canSelfD(true)
 , selfDCountdown(0)
-, canSubmerge(false)
-, canfly(false)
-, canmove(false)
-, canhover(false)
-, floater(false)
 , builder(false)
 , activateWhenBuilt(false)
 , onoffable(false)
@@ -146,18 +147,31 @@ UnitDef::UnitDef()
 , reclaimable(false)
 , capturable(false)
 , repairable(false)
+
+, canmove(false)
+, canHover(false)
+, canAttack(false)
+, canFight(false)
+, canPatrol(false)
+, canGuard(false)
+, canRepeat(false)
+, canResurrect(false)
+, canCapture(false)
+, canCloak(false)
+, canSelfD(true)
+, canKamikaze(false)
+
 , canRestore(false)
 , canRepair(false)
-, canSelfRepair(false)
 , canReclaim(false)
-, canAttack(false)
-, canPatrol(false)
-, canFight(false)
-, canGuard(false)
 , canAssist(false)
+
 , canBeAssisted(false)
-, canRepeat(false)
+, canSelfRepair(false)
+
 , canFireControl(false)
+, canManualFire(false)
+
 , fireState(FIRESTATE_HOLDFIRE)
 , moveState(MOVESTATE_HOLDPOS)
 , wingDrag(0.0f)
@@ -201,7 +215,6 @@ UnitDef::UnitDef()
 , transportUnloadMethod(0)
 , fallSpeed(0.0f)
 , unitFallSpeed(0.0f)
-, canCloak(false)
 , startCloaked(false)
 , cloakCost(0.0f)
 , cloakCostMoving(0.0f)
@@ -209,18 +222,13 @@ UnitDef::UnitDef()
 , decloakSpherical(false)
 , decloakOnFire(false)
 , cloakTimeout(0)
-, canKamikaze(false)
 , kamikazeDist(0.0f)
 , kamikazeUseLOS(false)
 , targfac(false)
-, canManualFire(false)
 , needGeo(false)
 , isFeature(false)
 , hideDamage(false)
-, isCommander(false)
 , showPlayerName(false)
-, canResurrect(false)
-, canCapture(false)
 , highTrajectoryType(0)
 , noChaseCategory(0)
 , leaveTracks(false)
@@ -261,28 +269,17 @@ UnitDef::UnitDef()
 
 
 UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
-: name(unitName)
-, id(id)
-, collisionVolume(NULL)
-, decoyDef(NULL)
-, techLevel(-1)
-, buildPic(NULL)
-, movedata(NULL)
-, trackType(0)
-, buildingDecalType(-1)
-, realMetalCost(0.0f)
-, realEnergyCost(0.0f)
-, realMetalUpkeep(0.0f)
-, realEnergyUpkeep(0.0f)
-, realBuildTime(0.0f)
 {
+	// rely on default-ctor to initialize all members
+	*this = UnitDef();
+	this->id = id;
+
+	name = unitName;
 	humanName = udTable.GetString("name", "");
 	tooltip = udTable.GetString("description", name);
 	buildPicName = udTable.GetString("buildPic", "");
 	decoyName = udTable.GetString("decoyFor", "");
 
-	isCommander = udTable.GetBool("commander", false);
-
 	metalStorage  = udTable.GetFloat("metalStorage",  0.0f);
 	energyStorage = udTable.GetFloat("energyStorage", 0.0f);
 
@@ -305,6 +302,7 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 	// (do not allow it to be zero or negative in either case)
 	metalCost = std::max(1.0f, udTable.GetFloat("buildCostMetal", 0.0f));
 	mass = Clamp(udTable.GetFloat("mass", metalCost), CSolidObject::MINIMUM_MASS, CSolidObject::MAXIMUM_MASS);
+	crushResistance = udTable.GetFloat("crushResistance", mass);
 
 	energyCost = udTable.GetFloat("buildCostEnergy", 0.0f);
 	buildTime = std::max(0.1f, udTable.GetFloat("buildTime", 0.0f)); //avoid some nasty divide by 0
@@ -319,17 +317,6 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 		airLosRadius = airLosRadius * modInfo.airLosMul / (SQUARE_SIZE * (1 << modInfo.airMipLevel));
 	}
 
-	canSubmerge = udTable.GetBool("canSubmerge", false);
-	canfly      = udTable.GetBool("canFly",      false);
-	canmove     = udTable.GetBool("canMove",     false);
-	reclaimable = udTable.GetBool("reclaimable", true);
-	capturable  = udTable.GetBool("capturable",  true);
-	repairable  = udTable.GetBool("repairable",  true);
-	canAttack   = udTable.GetBool("canAttack",   true);
-	canFight    = udTable.GetBool("canFight",    true);
-	canPatrol   = udTable.GetBool("canPatrol",   true);
-	canGuard    = udTable.GetBool("canGuard",    true);
-	canRepeat   = udTable.GetBool("canRepeat",   true);
 
 	builder = udTable.GetBool("builder", false);
 	buildRange3D = udTable.GetBool("buildRange3D", false);
@@ -348,19 +335,40 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 	captureSpeed   = udTable.GetFloat("captureSpeed",   buildSpeed);
 	terraformSpeed = udTable.GetFloat("terraformSpeed", buildSpeed);
 
-	canRestore = udTable.GetBool("canRestore", builder);
-	canRepair  = udTable.GetBool("canRepair",  builder);
-	canReclaim = udTable.GetBool("canReclaim", builder);
-	canAssist  = udTable.GetBool("canAssist",  builder);
+	reclaimable  = udTable.GetBool("reclaimable",  true);
+	capturable   = udTable.GetBool("capturable",   true);
+	repairable   = udTable.GetBool("repairable",   true);
+
+	canmove      = udTable.GetBool("canMove",         false);
+	canHover     = udTable.GetBool("canHover",        false);
+	canAttack    = udTable.GetBool("canAttack",       true);
+	canFight     = udTable.GetBool("canFight",        true);
+	canPatrol    = udTable.GetBool("canPatrol",       true);
+	canGuard     = udTable.GetBool("canGuard",        true);
+	canRepeat    = udTable.GetBool("canRepeat",       true);
+	canResurrect = udTable.GetBool("canResurrect",    false);
+	canCapture   = udTable.GetBool("canCapture",      false);
+	canCloak     = udTable.GetBool("canCloak",        (udTable.GetFloat("cloakCost", 0.0f) != 0.0f));
+	canSelfD     = udTable.GetBool("canSelfDestruct", true);
+	canKamikaze  = udTable.GetBool("kamikaze",        false);
+
+	canRestore   = udTable.GetBool("canRestore", builder);
+	canRepair    = udTable.GetBool("canRepair",  builder);
+	canReclaim   = udTable.GetBool("canReclaim", builder);
+	canAssist    = udTable.GetBool("canAssist",  builder);
 
 	canBeAssisted = udTable.GetBool("canBeAssisted", true);
 	canSelfRepair = udTable.GetBool("canSelfRepair", false);
+
+	canFireControl = !udTable.GetBool("noAutoFire", false);
+	canManualFire = udTable.GetBool("canManualFire", udTable.GetBool("canDGun", false));
+
 	fullHealthFactory = udTable.GetBool("fullHealthFactory", false);
 	factoryHeadingTakeoff = udTable.GetBool("factoryHeadingTakeoff", true);
 
 	upright = udTable.GetBool("upright", false);
+	blocking = udTable.GetBool("blocking", true);
 	collide = udTable.GetBool("collide", true);
-	onoffable = udTable.GetBool("onoffable", false);
 
 	const float maxSlopeDeg = Clamp(udTable.GetFloat("maxSlope", 0.0f), 0.0f, 89.0f);
 	const float maxSlopeRad = maxSlopeDeg * (PI / 180.0f);
@@ -374,24 +382,13 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 	minCollisionSpeed = udTable.GetFloat("minCollisionSpeed", 1.0f);
 	slideTolerance = udTable.GetFloat("slideTolerance", 0.0f); // disabled
 	pushResistant = udTable.GetBool("pushResistant", false);
-
-	canSelfD = udTable.GetBool("canSelfDestruct", true);
 	selfDCountdown = udTable.GetInt("selfDestructCountdown", 5);
 
 	speed  = udTable.GetFloat("maxVelocity", 0.0f) * GAME_SPEED;
-	rSpeed = udTable.GetFloat("maxReverseVelocity", 0.0f) * GAME_SPEED;
 	speed  = fabs(speed);
+	rSpeed = udTable.GetFloat("maxReverseVelocity", 0.0f) * GAME_SPEED;
 	rSpeed = fabs(rSpeed);
 
-	maxAcc = fabs(udTable.GetFloat("acceleration", 0.5f)); // no negative values
-	maxDec = fabs(udTable.GetFloat("brakeRate", 3.0f * maxAcc)) * (canfly? 0.1f: 1.0f); // no negative values
-
-	turnRate    = udTable.GetFloat("turnRate", 0.0f);
-	turnInPlace = udTable.GetBool("turnInPlace", true);
-	turnInPlaceSpeedLimit = ((turnRate / SPRING_CIRCLE_DIVS) * ((PI + PI) * SQUARE_SIZE)) * (speed / GAME_SPEED);
-	turnInPlaceSpeedLimit = udTable.GetFloat("turnInPlaceSpeedLimit", std::min(speed, turnInPlaceSpeedLimit));
-
-	canFireControl = !udTable.GetBool("noAutoFire", false);
 	fireState = udTable.GetInt("fireState", canFireControl? FIRESTATE_NONE: FIRESTATE_FIREATWILL);
 	fireState = std::min(fireState, int(FIRESTATE_FIREATWILL));
 	moveState = udTable.GetInt("moveState", (canmove && speed > 0.0f)? MOVESTATE_NONE: MOVESTATE_MANEUVER);
@@ -418,17 +415,15 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 	sonarStealth   = udTable.GetBool("sonarStealth",       false);
 	targfac        = udTable.GetBool("isTargetingUpgrade", false);
 	isFeature      = udTable.GetBool("isFeature",          false);
-	canResurrect   = udTable.GetBool("canResurrect",       false);
-	canCapture     = udTable.GetBool("canCapture",         false);
 	hideDamage     = udTable.GetBool("hideDamage",         false);
 	showPlayerName = udTable.GetBool("showPlayerName",     false);
 
-	cloakCost = udTable.GetFloat("cloakCost", -1.0f);
-	cloakCostMoving = udTable.GetFloat("cloakCostMoving", -1.0f);
-	if (cloakCostMoving < 0) {
+	cloakCost = udTable.GetFloat("cloakCost", 0.0f);
+	cloakCostMoving = udTable.GetFloat("cloakCostMoving", 0.0f);
+
+	if (cloakCostMoving < 0.0f) {
 		cloakCostMoving = cloakCost;
 	}
-	canCloak = (cloakCost >= 0);
 
 	startCloaked     = udTable.GetBool("initCloaked", false);
 	decloakDistance  = udTable.GetFloat("minCloakDistance", 0.0f);
@@ -438,16 +433,16 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 
 	highTrajectoryType = udTable.GetInt("highTrajectory", 0);
 
-	canKamikaze = udTable.GetBool("kamikaze", false);
-	kamikazeDist = udTable.GetFloat("kamikazeDistance", -25.0f) + 25.0f; //we count 3d distance while ta count 2d distance so increase slightly
+	// we count 3d distance while ta count 2d distance so increase slightly
+	kamikazeDist = udTable.GetFloat("kamikazeDistance", -25.0f) + 25.0f;
 	kamikazeUseLOS = udTable.GetBool("kamikazeUseLOS", false);
 
 	showNanoFrame = udTable.GetBool("showNanoFrame", true);
 	showNanoSpray = udTable.GetBool("showNanoSpray", true);
 	nanoColor = udTable.GetFloat3("nanoColor", float3(0.2f,0.7f,0.2f));
 
-	canhover = udTable.GetBool("canHover", false);
-	floater = udTable.GetBool("floater", udTable.KeyExists("WaterLine"));
+	canSubmerge = udTable.GetBool("canSubmerge", false);
+	canfly      = udTable.GetBool("canFly",      false);
 
 	airStrafe      = udTable.GetBool("airStrafe", true);
 	hoverAttack    = udTable.GetBool("hoverAttack", false);
@@ -456,6 +451,16 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 	bankingAllowed = udTable.GetBool("bankingAllowed", true);
 	useSmoothMesh  = udTable.GetBool("useSmoothMesh", true);
 
+
+	maxAcc = fabs(udTable.GetFloat("acceleration", 0.5f)); // no negative values
+	maxDec = fabs(udTable.GetFloat("brakeRate", 3.0f * maxAcc)) * (canfly? 0.1f: 1.0f); // no negative values
+
+	turnRate    = udTable.GetFloat("turnRate", 0.0f);
+	turnInPlace = udTable.GetBool("turnInPlace", true);
+	turnInPlaceSpeedLimit = ((turnRate / SPRING_CIRCLE_DIVS) * ((PI + PI) * SQUARE_SIZE)) * (speed / GAME_SPEED);
+	turnInPlaceSpeedLimit = udTable.GetFloat("turnInPlaceSpeedLimit", std::min(speed, turnInPlaceSpeedLimit));
+
+
 	transportSize     = udTable.GetInt("transportSize",      0);
 	minTransportSize  = udTable.GetInt("minTransportSize",   0);
 	transportCapacity = udTable.GetInt("transportCapacity",  0);
@@ -471,15 +476,7 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 	transportByEnemy  = udTable.GetBool("transportByEnemy",  true);
 	fallSpeed         = udTable.GetFloat("fallSpeed",    0.2);
 	unitFallSpeed     = udTable.GetFloat("unitFallSpeed",  0);
-	transportUnloadMethod	= udTable.GetInt("transportUnloadMethod" , 0);
-
-	// modrules transport settings
-	if ((!modInfo.transportAir    && canfly)   ||
-	    (!modInfo.transportShip   && floater)  ||
-	    (!modInfo.transportHover  && canhover) ||
-	    (!modInfo.transportGround && !canhover && !floater && !canfly)) {
- 		cantBeTransported = true;
-	}
+	transportUnloadMethod = udTable.GetInt("transportUnloadMethod" , 0);
 
 	wingDrag     = udTable.GetFloat("wingDrag",     0.07f);  // drag caused by wings
 	wingDrag     = Clamp(wingDrag, 0.0f, 1.0f);
@@ -503,10 +500,7 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 	refuelTime = udTable.GetFloat("refuelTime", 5.0f);
 	minAirBasePower = udTable.GetFloat("minAirBasePower", 0.0f);
 	maxThisUnit = udTable.GetInt("unitRestricted", MAX_UNITS);
-
-	if (gameSetup->restrictedUnits.find(name) != gameSetup->restrictedUnits.end()) {
-		maxThisUnit = std::min(maxThisUnit, gameSetup->restrictedUnits.find(name)->second);
-	}
+	maxThisUnit = std::min(maxThisUnit, gameSetup->GetRestrictedUnitLimit(name, MAX_UNITS));
 
 	categoryString = udTable.GetString("category", "");
 
@@ -524,13 +518,22 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 	LuaTable weaponsTable = udTable.SubTable("weapons");
 	ParseWeaponsTable(weaponsTable);
 
-	canManualFire = udTable.GetBool("canDGun", false); // NOTE: deprecated, remove after 0.83.*
-	canManualFire = udTable.GetBool("canManualFire", canManualFire);
 	needGeo = false;
 
 	extractRange = mapInfo->map.extractorRadius * int(extractsMetal > 0.0f);
 	extractSquare = udTable.GetBool("extractSquare", false);
 
+	const bool canFloat = udTable.GetBool("floater", udTable.KeyExists("WaterLine"));
+
+	// modrules transport settings
+	// FIXME: do we want to check moveData->moveType for these?
+	if ((!modInfo.transportAir    && canfly)   ||
+		(!modInfo.transportShip   && canFloat) ||
+		(!modInfo.transportHover  && canHover) ||
+		(!modInfo.transportGround && !canHover && !canFloat && !canfly)) {
+ 		cantBeTransported = true;
+	}
+
 	// aircraft have MoveTypes but no MoveData;
 	// static structures have no use for either
 	// (but get StaticMoveType instances)
@@ -547,19 +550,20 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 		if (LOG_IS_ENABLED(L_WARNING)) {
 			const char* typeStr = NULL;
 			const char* wantedTypeStr = NULL;
-			if (canhover) {
+
+			if (canHover) {
 				if (movedata->moveType != MoveData::Hover_Move) {
-					typeStr       = "canhover";
+					typeStr       = "canHover";
 					wantedTypeStr = "hover";
 				}
-			} else if (floater) {
+			} else if (canFloat) {
 				if (movedata->moveType != MoveData::Ship_Move) {
-					typeStr       = "floater";
+					typeStr       = "canFloat";
 					wantedTypeStr = "ship";
 				}
 			} else {
 				if (movedata->moveType != MoveData::Ground_Move) {
-					typeStr       = "!(canhover || floater)";
+					typeStr       = "!(canHover || canFloat)";
 					wantedTypeStr = "ground";
 				}
 			}
@@ -575,10 +579,14 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 
 	if (movedata == NULL) {
 		upright = upright || !canfly;
+		floatOnWater = canFloat;
 	} else {
 		upright = upright ||
 			(movedata->moveType == MoveData::Hover_Move) ||
 			(movedata->moveType == MoveData::Ship_Move);
+		floatOnWater =
+			(movedata->moveType == MoveData::Hover_Move) ||
+			(movedata->moveType == MoveData::Ship_Move);
 	}
 
 	if (IsAirUnit()) {
@@ -628,6 +636,7 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 	}
 
 	activateWhenBuilt = udTable.GetBool("activateWhenBuilt", false);
+	onoffable = udTable.GetBool("onoffable", false);
 
 	// footprint sizes are assumed to be expressed in TA-engine units;
 	// Spring's heightmap resolution is double the footprint (yardmap)
@@ -689,7 +698,7 @@ UnitDef::UnitDef(const LuaTable& udTable, const std::string& unitName, int id)
 	seismicRadius    = udTable.GetInt("seismicDistance", 0);
 	seismicSignature = udTable.GetFloat("seismicSignature", -1.0f);
 	if (seismicSignature == -1.0f) {
-		if (!floater && !canhover && !canfly) {
+		if (!canFloat && !canHover && !canfly) {
 			seismicSignature = sqrt(mass / 100.0f);
 		} else {
 			seismicSignature = 0.0f;
@@ -943,7 +952,7 @@ bool UnitDef::IsAllowedTerrainHeight(float rawHeight, float* clampedHeight) cons
 		}
 	}
 
-	if (floater || canhover) {
+	if (floatOnWater) {
 		// if we are a surface unit, <maxDepth> is irrelevant
 		// (eg. hovercraft may be dropped anywhere over water)
 		maxDepth = +10e6f;
