@@ -4,11 +4,14 @@
 #define __FACTORY_H__
 
 #include "Building.h"
+#include "Sim/Units/CommandAI/Command.h"
 #include "System/float3.h"
 
-#include <string>
-
 struct UnitDef;
+struct Command;
+class CFactory;
+
+typedef void (*FinishBuildCallBackFunc) (CFactory*, const Command&);
 
 class CFactory : public CBuilding
 {
@@ -19,9 +22,15 @@ public:
 	virtual ~CFactory();
 
 	void PostLoad();
+
+	void StartBuild(const UnitDef* buildeeDef);
+	void UpdateBuild(CUnit* buildee);
+	void FinishBuild(CUnit* buildee);
 	void StopBuild();
-	void StartBuild(const UnitDef* ud);
+	bool QueueBuild(const UnitDef* buildeeDef, const Command& buildCmd, FinishBuildCallBackFunc buildCB);
+
 	void Update();
+	void SlowUpdate();
 	void DependentDied(CObject* o);
 	void CreateNanoParticle(bool highPriority = false);
 
@@ -30,24 +39,25 @@ public:
 	int GetBuildPiece();
 
 	void PreInit(const UnitDef* def, int team, int facing, const float3& position, bool build);
+	bool ChangeTeam(int newTeam, ChangeType type);
 
 	float buildSpeed;
 
-	/// if we have a unit that we want to start to nanolath when script is ready
-	bool quedBuild;
-	const UnitDef* nextBuild;
-	std::string nextBuildName;
-	CUnit* curBuild;            ///< unit that we are nanolathing
+	/// whether we are currently opening in preparation to start building
 	bool opening;
 
-	int lastBuild;              ///< last frame we wanted to build something
-
-	void SlowUpdate();
-	bool ChangeTeam(int newTeam, ChangeType type);
+	const UnitDef* curBuildDef;
+	CUnit* curBuild;
 
 private:
 	void SendToEmptySpot(CUnit* unit);
 	void AssignBuildeeOrders(CUnit* unit);
+
+	int nextBuildUnitDefID;
+	int lastBuildUpdateFrame;
+
+	FinishBuildCallBackFunc finishedBuildFunc;
+	Command finishedBuildCommand;
 };
 
 #endif // __FACTORY_H__
