@@ -72,7 +72,7 @@ void CMissileLauncher::FireImpl()
 	if (onlyForward && dynamic_cast<CStrafeAirMoveType*>(owner->moveType))
 		startSpeed += owner->speed;
 
-	new CMissileProjectile(weaponMuzzlePos, startSpeed, owner, areaOfEffect,
+	new CMissileProjectile(weaponMuzzlePos, startSpeed, owner, damageAreaOfEffect,
 			projectileSpeed,
 			weaponDef->flighttime == 0
                 ? (int) (range / projectileSpeed + 25 * weaponDef->selfExplode)
@@ -95,32 +95,36 @@ bool CMissileLauncher::TryTarget(const float3& pos, bool userTarget, CUnit* unit
 		// trajectory (parabolic vs. linear ground intersection; in
 		// the latter case, HaveFreeLineOfFire() checks the NOGROUND
 		// collision flag for us)
-		float3 flatdir(dir.x, 0, dir.z);
-		dir.Normalize();
-		float flatlength = flatdir.Length();
+		float3 flatDir(dir.x, 0, dir.z);
+		dir.SafeNormalize();
+		float flatLength = flatDir.Length();
 
-		if (flatlength == 0)
+		if (flatLength == 0)
 			return true;
 
-		flatdir /= flatlength;
+		flatDir /= flatLength;
 
 		const float linear = dir.y + weaponDef->trajectoryHeight;
-		const float quadratic = -weaponDef->trajectoryHeight / flatlength;
+		const float quadratic = -weaponDef->trajectoryHeight / flatLength;
 		const float gc = ((collisionFlags & Collision::NOGROUND) == 0)?
-			ground->TrajectoryGroundCol(weaponMuzzlePos, flatdir, flatlength - 30, linear, quadratic):
+			ground->TrajectoryGroundCol(weaponMuzzlePos, flatDir, flatLength - 30, linear, quadratic):
 			-1.0f;
+		const float modFlatLength = flatLength - 30.0f;
 
 		if (gc > 0.0f)
 			return false;
 
-		if (avoidFriendly && TraceRay::TestTrajectoryAllyCone(weaponMuzzlePos, flatdir, flatlength - 30, linear, quadratic, 0, 8, owner->allyteam, owner)) {
+		if (avoidFriendly && TraceRay::TestTrajectoryCone(weaponMuzzlePos, flatDir, modFlatLength, linear, quadratic, 0, 8, owner->allyteam, true, false, false, owner)) {
 			return false;
 		}
-		if (avoidNeutral && TraceRay::TestTrajectoryNeutralCone(weaponMuzzlePos, flatdir, flatlength - 30, linear, quadratic, 0, 8, owner)) {
+		if (avoidNeutral && TraceRay::TestTrajectoryCone(weaponMuzzlePos, flatDir, modFlatLength, linear, quadratic, 0, 8, owner->allyteam, false, true, false, owner)) {
+			return false;
+		}
+		if (avoidFeature && TraceRay::TestTrajectoryCone(weaponMuzzlePos, flatDir, modFlatLength, linear, quadratic, 0, 8, owner->allyteam, false, false, true, owner)) {
 			return false;
 		}
 	} else {
-		float length = dir.Length();
+		const float length = dir.Length();
 		if (length == 0)
 			return true;
 
@@ -132,15 +136,18 @@ bool CMissileLauncher::TryTarget(const float3& pos, bool userTarget, CUnit* unit
 			}
 		} else {
 			float3 goaldir = pos - owner->pos;
-			goaldir.Normalize();
+			goaldir.SafeNormalize();
 			if (owner->frontdir.dot(goaldir) < maxAngleDif)
 				return false;
 		}
 
-		if (avoidFriendly && TraceRay::TestAllyCone(weaponMuzzlePos, dir, length, (accuracy + sprayAngle), owner->allyteam, owner)) {
+		if (avoidFriendly && TraceRay::TestCone(weaponMuzzlePos, dir, length, (accuracy + sprayAngle), owner->allyteam, true, false, false, owner)) {
 			return false;
 		}
-		if (avoidNeutral && TraceRay::TestNeutralCone(weaponMuzzlePos, dir, length, (accuracy + sprayAngle), owner)) {
+		if (avoidNeutral && TraceRay::TestCone(weaponMuzzlePos, dir, length, (accuracy + sprayAngle), owner->allyteam, false, true, false, owner)) {
+			return false;
+		}
+		if (avoidFeature && TraceRay::TestCone(weaponMuzzlePos, dir, length, (accuracy + sprayAngle), owner->allyteam, false, false, true, owner)) {
 			return false;
 		}
 	}
