@@ -4,6 +4,8 @@
 #define PLASMAREPULSER_H
 
 #include "Weapon.h"
+#include <list>
+#include <set>
 
 class CProjectile;
 class CRepulseGfx;
@@ -16,19 +18,17 @@ class CPlasmaRepulser :
 public:
 	CPlasmaRepulser(CUnit* owner);
 	~CPlasmaRepulser(void);
-	void Update(void);
-	void NewProjectile(CWeaponProjectile* p);
-	float NewBeam(CWeapon* emitter, float3 start, float3 dir, float length, float3& newDir);
-	bool BeamIntercepted(CWeapon* emitter, float damageMultiplier = 1.0f);		//returns true if its a repulsing shield
 	void Init(void);
-
-	std::list<CWeaponProjectile*> incoming;
-	std::list<CWeaponProjectile*> hasGfx;
-	std::list<CShieldPartProjectile*> visibleShieldParts;
-
 	void DependentDied(CObject* o);
+
+	void Update(void);
 	void SlowUpdate(void);
 
+	void NewProjectile(CWeaponProjectile* p);
+	float NewBeam(CWeapon* emitter, float3 start, float3 dir, float length, float3& newDir);
+	bool BeamIntercepted(CWeapon* emitter, float damageMultiplier = 1.0f); // returns true if we are a repulsing shield
+
+public:
 	float curPower;
 
 	float radius;
@@ -41,8 +41,12 @@ public:
 	bool wasDrawn;
 	bool startShowingShield;
 
-private:	
+private:
 	virtual void FireImpl() {};
+
+private:
+	std::set<CWeaponProjectile*> hasGfx;
+	std::list<CShieldPartProjectile*> visibleShieldParts;
 };
 
 #endif
