@@ -6,6 +6,7 @@
  */
 
 #include "Backend.h"
+#include "FramePrefixer.h"
 #include "Level.h" // for LOG_LEVEL_*
 #include "System/maindefines.h"
 
@@ -40,8 +41,14 @@ static inline FILE* log_chooseStream(int level) {
 static void log_sink_record_console(const char* section, int level,
 		const char* record)
 {
+	char framePrefix[128] = {'\0'};
+	log_framePrefixer_createPrefix(framePrefix, sizeof(framePrefix));
+
 	FILE* outStream = log_chooseStream(level);
-	FPRINTF(outStream, "%s\n", record);
+	FPRINTF(outStream, "%s%s\n", framePrefix, record);
+	// *printf does not always flush after a newline
+	// (eg. if stdout is being redirected to a file)
+	fflush(outStream);
 }
 
 ///@}
