@@ -18,6 +18,9 @@ public:
 	void PlaySample(size_t id, const CUnit* u, float volume = 1.0f) {}
 	void PlaySample(size_t id, const CWorldObject* p, float volume = 1.0f) {}
 
+	void PlayRandomSample(const GuiSoundSet& soundSet, const CUnit* unit) {}
+	void PlayRandomSample(const GuiSoundSet& soundSet, const float3& pos) {}
+
 	void StreamPlay(const std::string& path, float volume = 1.0f, bool enqueue = false) {}
 
 	void StreamStop() {}
