@@ -8,14 +8,17 @@
 #include <set>
 #include <string>
 #include <map>
+#include <vector>
 #include <boost/ptr_container/ptr_vector.hpp>
 #include <boost/shared_ptr.hpp>
 #include <boost/thread/thread.hpp>
 #include <boost/thread/recursive_mutex.hpp>
 
-#include "float3.h"
+#include "System/float3.h"
 
-class SoundSource;
+#include "SoundItem.h"
+
+class CSoundSource;
 class SoundBuffer;
 class SoundItem;
 
@@ -27,10 +30,11 @@ public:
 	CSound();
 	virtual ~CSound();
 
-	virtual bool HasSoundItem(const std::string& name);
+	virtual bool HasSoundItem(const std::string& name) const;
 	virtual size_t GetSoundId(const std::string& name, bool hardFail = true);
+	SoundItem* GetSoundItem(size_t id) const;
 
-	virtual SoundSource* GetNextBestSource(bool lock = true);
+	virtual CSoundSource* GetNextBestSource(bool lock = true);
 
 	virtual void UpdateListener(const float3& campos, const float3& camdir, const float3& camup, float lastFrameTime);
 	virtual void NewFrame();
@@ -47,21 +51,23 @@ public:
 	virtual void PrintDebugInfo();
 	virtual bool LoadSoundDefs(const std::string& fileName);
 
+	const float3& GetListenerPos() const {
+		return myPos;
+	}
+
+private:
+	typedef std::map<std::string, std::string> soundItemDef;
+	typedef std::map<std::string, soundItemDef> soundItemDefMap;
+
 private:
 	void StartThread(int maxSounds);
 	void Update();
 
-	typedef std::map<std::string, std::string> soundItemDef;
-	typedef std::map<std::string, soundItemDef> soundItemDefMap;
-
 	size_t MakeItemFromDef(const soundItemDef& itemDef);
 
-	friend class EffectChannel;
-	// this is used by EffectChannel in AudioChannel.cpp
-	virtual void PlaySample(size_t id, const float3 &p, const float3& velocity, float volume, bool relative);
-
 	size_t LoadSoundBuffer(const std::string& filename, bool hardFail);
 
+private:
 	float masterVolume;
 	bool mute;
 	/// we do not play if minimized / iconified
@@ -69,7 +75,7 @@ private:
 	bool pitchAdjust;
 
 	typedef std::map<std::string, size_t> soundMapT;
-	typedef boost::ptr_vector<SoundItem> soundVecT;
+	typedef std::vector<SoundItem*> soundVecT;
 	soundMapT soundMap;
 	soundVecT sounds;
 
@@ -77,17 +83,13 @@ private:
 	float3 myPos;
 	float3 prevVelocity;
 
-	typedef boost::ptr_vector<SoundSource> sourceVecT;
+	typedef boost::ptr_vector<CSoundSource> sourceVecT;
 	sourceVecT sources;
 
-	unsigned numEmptyPlayRequests;
-	unsigned numAbortedPlays;
-
 	soundItemDef defaultItem;
 	soundItemDefMap soundItemDefs;
 
 	boost::thread* soundThread;
-	boost::recursive_mutex soundMutex;
 
 	volatile bool soundThreadQuit;
 };
