@@ -45,7 +45,7 @@
 //		#include <stdlib.h>  //
 //		#include <streamio>  //
 //
-//		#include "mmgr.h"    // mmgr.h MUST come next
+//		#include "System/mmgr.h"    // mmgr.h MUST come next
 //
 //		#include "myfile1.h" // Project includes MUST come last
 //		#include "myfile2.h" //
@@ -53,7 +53,6 @@
 //
 // ---------------------------------------------------------------------------------------------------------------------------------
 
-#include "StdAfx.h"
 
 #ifdef USE_MMGR
 
@@ -77,7 +76,7 @@ using std::new_handler;
 #include <execinfo.h>
 #endif
 
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 // ---------------------------------------------------------------------------------------------------------------------------------
 // -DOC- If you're like me, it's hard to gain trust in foreign code. This memory manager will try to INDUCE your code to crash (for
@@ -692,60 +691,6 @@ void	m_setOwner(const char *file, const unsigned int line, const char *func)
 // memory tracking routines.
 // ---------------------------------------------------------------------------------------------------------------------------------
 
-void	*operator new(size_t reportedSize)
-{
-	boost::recursive_mutex::scoped_lock scoped_lock(get_mutex());
-
-  #ifdef TEST_MEMORY_MANAGER
-	log("ENTER: new");
-	#endif
-
-	// ANSI says: allocation requests of 0 bytes will still return a valid value
-
-	if (reportedSize == 0) reportedSize = 1;
-
-	// ANSI says: loop continuously because the error handler could possibly free up some memory
-
-	for(;;)
-	{
-		// Try the allocation
-
-		void	*ptr = m_allocator(sourceFile, sourceLine, sourceFunc, m_alloc_new, reportedSize);
-		if (ptr)
-		{
-			#ifdef TEST_MEMORY_MANAGER
-			log("EXIT : new");
-			#endif
-			return ptr;
-		}
-
-		// There isn't a way to determine the new handler, except through setting it. So we'll just set it to NULL, then
-		// set it back again.
-
-		new_handler	nh = std::set_new_handler(0);
-		std::set_new_handler(nh);
-
-		// If there is an error handler, call it
-
-		if (nh)
-		{
-			(*nh)();
-		}
-
-		// Otherwise, throw the exception
-
-		else
-		{
-			#ifdef TEST_MEMORY_MANAGER
-			log("EXIT : new");
-			#endif
-			throw std::bad_alloc();
-		}
-	}
-}
-
-// ---------------------------------------------------------------------------------------------------------------------------------
-
 void	*operator new[](size_t reportedSize)
 {
 	boost::recursive_mutex::scoped_lock scoped_lock(get_mutex());
@@ -806,7 +751,7 @@ void	*operator new[](size_t reportedSize)
 // our memory tracking routines.
 // ---------------------------------------------------------------------------------------------------------------------------------
 
-void	*operator new(size_t reportedSize, const char *sourceFile, int sourceLine)
+void	*operator new(size_t reportedSize, const char *sourceFile = "??", int sourceLine = -1)
 {
 	boost::recursive_mutex::scoped_lock scoped_lock(get_mutex());
 
