@@ -4,7 +4,7 @@
 
 int main() {
 	TestConnection con;
-	con.Connect("taspringmaster.clan-sy.com", 8200);
+	con.Connect("lobby.springrts.com", 8200);
 	while (true) {
 		con.Run();
 	}
