@@ -316,6 +316,9 @@ EXPORT(int) Init(bool isServer, int id)
 #ifndef DEBUG
 		log_filter_section_setMinLevel(LOG_SECTION_UNITSYNC, LOG_LEVEL_INFO);
 #endif
+		if (archiveScanner || vfsHandler){
+			FileSystemInitializer::Cleanup(); //reinitialize filesystem to detect new files
+		}
 		if (!configHandler) {
 			ConfigHandler::Instantiate(); // use the default config file
 		}
